summaryrefslogtreecommitdiffstats
path: root/src/gui/widgets
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
commit458efa7b0c935cbaafa2791021a5f8f7241aa876 (patch)
tree624583f2873febe23770bee3fa94b5c24bd59f4f /src/gui/widgets
parent747037b72944ae2c02962b7c5c96e0a7f8852e38 (diff)
downloadrosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.tar.gz
rosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.zip
Initial TQt4 port of Rosegarden
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1230242 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/widgets')
-rw-r--r--src/gui/widgets/AudioFaderBox.cpp16
-rw-r--r--src/gui/widgets/AudioFaderBox.h5
-rw-r--r--src/gui/widgets/AudioListItem.h14
-rw-r--r--src/gui/widgets/AudioListView.cpp4
-rw-r--r--src/gui/widgets/AudioListView.h2
-rw-r--r--src/gui/widgets/AudioRouteMenu.cpp14
-rw-r--r--src/gui/widgets/AudioRouteMenu.h5
-rw-r--r--src/gui/widgets/AudioVUMeter.cpp16
-rw-r--r--src/gui/widgets/AudioVUMeter.h6
-rw-r--r--src/gui/widgets/BigArrowButton.h6
-rw-r--r--src/gui/widgets/CollapsingFrame.cpp14
-rw-r--r--src/gui/widgets/CollapsingFrame.h7
-rw-r--r--src/gui/widgets/ColourTable.cpp4
-rw-r--r--src/gui/widgets/ColourTable.h5
-rw-r--r--src/gui/widgets/ColourTableItem.h2
-rw-r--r--src/gui/widgets/CurrentProgressDialog.h7
-rw-r--r--src/gui/widgets/DiatonicPitchChooser.cpp12
-rw-r--r--src/gui/widgets/DiatonicPitchChooser.h5
-rw-r--r--src/gui/widgets/Fader.cpp76
-rw-r--r--src/gui/widgets/Fader.h9
-rw-r--r--src/gui/widgets/HSpinBox.cpp12
-rw-r--r--src/gui/widgets/HSpinBox.h6
-rw-r--r--src/gui/widgets/Label.h7
-rw-r--r--src/gui/widgets/MidiFaderWidget.h5
-rw-r--r--src/gui/widgets/PitchChooser.cpp8
-rw-r--r--src/gui/widgets/PitchChooser.h5
-rw-r--r--src/gui/widgets/PitchDragLabel.cpp10
-rw-r--r--src/gui/widgets/PitchDragLabel.h7
-rw-r--r--src/gui/widgets/PluginControl.cpp36
-rw-r--r--src/gui/widgets/PluginControl.h9
-rw-r--r--src/gui/widgets/ProgressBar.h1
-rw-r--r--src/gui/widgets/ProgressDialog.cpp14
-rw-r--r--src/gui/widgets/ProgressDialog.h1
-rw-r--r--src/gui/widgets/QDeferScrollView.cpp6
-rw-r--r--src/gui/widgets/QDeferScrollView.h9
-rw-r--r--src/gui/widgets/QuantizeParameters.cpp92
-rw-r--r--src/gui/widgets/QuantizeParameters.h9
-rw-r--r--src/gui/widgets/RosegardenPopupMenu.h4
-rw-r--r--src/gui/widgets/Rotary.cpp44
-rw-r--r--src/gui/widgets/Rotary.h5
-rw-r--r--src/gui/widgets/ScrollBox.cpp24
-rw-r--r--src/gui/widgets/ScrollBox.h5
-rw-r--r--src/gui/widgets/ScrollBoxDialog.cpp4
-rw-r--r--src/gui/widgets/ScrollBoxDialog.h3
-rw-r--r--src/gui/widgets/SpinBox.cpp6
-rw-r--r--src/gui/widgets/SpinBox.h7
-rw-r--r--src/gui/widgets/TextFloat.cpp24
-rw-r--r--src/gui/widgets/TextFloat.h6
-rw-r--r--src/gui/widgets/TimeWidget.cpp114
-rw-r--r--src/gui/widgets/TimeWidget.h7
-rw-r--r--src/gui/widgets/TristateCheckBox.h7
-rw-r--r--src/gui/widgets/VUMeter.cpp48
-rw-r--r--src/gui/widgets/VUMeter.h9
-rw-r--r--src/gui/widgets/WheelyButton.h3
-rw-r--r--src/gui/widgets/ZoomSlider.h10
55 files changed, 410 insertions, 386 deletions
diff --git a/src/gui/widgets/AudioFaderBox.cpp b/src/gui/widgets/AudioFaderBox.cpp
index 27980e7..f544003 100644
--- a/src/gui/widgets/AudioFaderBox.cpp
+++ b/src/gui/widgets/AudioFaderBox.cpp
@@ -57,12 +57,12 @@
namespace Rosegarden
{
-AudioFaderBox::AudioFaderBox(TQWidget *parent,
+AudioFaderBox::AudioFaderBox(TQWidget *tqparent,
TQString id,
bool haveInOut,
const char *name):
- TQFrame(parent, name),
- m_signalMapper(new TQSignalMapper(this)),
+ TQFrame(tqparent, name),
+ m_signalMapper(new TQSignalMapper(TQT_TQOBJECT(this))),
m_id(id),
m_isStereo(false)
{
@@ -82,7 +82,7 @@ AudioFaderBox::AudioFaderBox(TQWidget *parent,
(plugin, i18n("Audio plugin button"));
m_plugins.push_back(plugin);
- m_signalMapper->setMapping(plugin, i);
+ m_signalMapper->setMapping(TQT_TQOBJECT(plugin), i);
connect(plugin, TQT_SIGNAL(clicked()),
m_signalMapper, TQT_SLOT(map()));
}
@@ -116,8 +116,8 @@ AudioFaderBox::AudioFaderBox(TQWidget *parent,
m_fader->setOutlineColour(GUIPalette::getColour(GUIPalette::PlaybackFaderOutline));
TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
- m_monoPixmap.load(TQString("%1/misc/mono.xpm").arg(pixmapDir));
- m_stereoPixmap.load(TQString("%1/misc/stereo.xpm").arg(pixmapDir));
+ m_monoPixmap.load(TQString("%1/misc/mono.xpm").tqarg(pixmapDir));
+ m_stereoPixmap.load(TQString("%1/misc/stereo.xpm").tqarg(pixmapDir));
m_pan = new Rotary(this, -100.0, 100.0, 1.0, 5.0, 0.0, 22,
Rotary::NoTicks, false, true);
@@ -244,8 +244,8 @@ bool
AudioFaderBox::owns(const TQObject *object)
{
return (object &&
- ((object->parent() == this) ||
- (object->parent() && (object->parent()->parent() == this))));
+ ((TQT_BASE_OBJECT(object->tqparent()) == TQT_BASE_OBJECT(this)) ||
+ (object->tqparent() && (TQT_BASE_OBJECT(object->tqparent()->tqparent()) == TQT_BASE_OBJECT(this)))));
}
void
diff --git a/src/gui/widgets/AudioFaderBox.h b/src/gui/widgets/AudioFaderBox.h
index 0c96b86..8c4f291 100644
--- a/src/gui/widgets/AudioFaderBox.h
+++ b/src/gui/widgets/AudioFaderBox.h
@@ -50,12 +50,13 @@ class AudioVUMeter;
class AudioRouteMenu;
-class AudioFaderBox : public QFrame
+class AudioFaderBox : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
- AudioFaderBox(TQWidget *parent,
+ AudioFaderBox(TQWidget *tqparent,
TQString id = "",
bool haveInOut = true,
const char *name = 0);
diff --git a/src/gui/widgets/AudioListItem.h b/src/gui/widgets/AudioListItem.h
index 410c374..7486bfa 100644
--- a/src/gui/widgets/AudioListItem.h
+++ b/src/gui/widgets/AudioListItem.h
@@ -33,32 +33,32 @@ namespace Rosegarden
class Segment;
-// Add an Id to a QListViewItem
+// Add an Id to a TQListViewItem
//
class AudioListItem : public KListViewItem
{
public:
- AudioListItem(KListView *parent):KListViewItem(parent),
+ AudioListItem(KListView *tqparent):KListViewItem(tqparent),
m_segment(0) {;}
- AudioListItem(KListViewItem *parent):KListViewItem(parent),
+ AudioListItem(KListViewItem *tqparent):KListViewItem(tqparent),
m_segment(0) {;}
- AudioListItem(KListView *parent,
+ AudioListItem(KListView *tqparent,
TQString label,
AudioFileId id):
- KListViewItem(parent,
+ KListViewItem(tqparent,
label,
"", "", "", "", "", "", ""),
m_id(id),
m_segment(0) {;}
- AudioListItem(KListViewItem *parent,
+ AudioListItem(KListViewItem *tqparent,
TQString label,
AudioFileId id):
- KListViewItem(parent,
+ KListViewItem(tqparent,
label,
"", "", "", "", "", "", ""),
m_id(id),
diff --git a/src/gui/widgets/AudioListView.cpp b/src/gui/widgets/AudioListView.cpp
index 3c75526..a840868 100644
--- a/src/gui/widgets/AudioListView.cpp
+++ b/src/gui/widgets/AudioListView.cpp
@@ -31,8 +31,8 @@
namespace Rosegarden {
-AudioListView::AudioListView(TQWidget *parent, const char *name)
- : KListView(parent, name)
+AudioListView::AudioListView(TQWidget *tqparent, const char *name)
+ : KListView(tqparent, name)
{
setDragEnabled(true);
setAcceptDrops(true);
diff --git a/src/gui/widgets/AudioListView.h b/src/gui/widgets/AudioListView.h
index 04c293e..e6bbaca 100644
--- a/src/gui/widgets/AudioListView.h
+++ b/src/gui/widgets/AudioListView.h
@@ -32,7 +32,7 @@ namespace Rosegarden {
class AudioListView : public KListView
{
public:
- AudioListView(TQWidget *parent = 0, const char *name = 0);
+ AudioListView(TQWidget *tqparent = 0, const char *name = 0);
protected:
bool acceptDrag(TQDropEvent* e) const;
diff --git a/src/gui/widgets/AudioRouteMenu.cpp b/src/gui/widgets/AudioRouteMenu.cpp
index 0cdc889..9af8ec3 100644
--- a/src/gui/widgets/AudioRouteMenu.cpp
+++ b/src/gui/widgets/AudioRouteMenu.cpp
@@ -133,7 +133,7 @@ AudioRouteMenu::slotShowMenu()
if (getNumEntries() == 0)
return ;
- RosegardenPopupMenu *menu = new RosegardenPopupMenu((TQWidget *)parent());
+ RosegardenPopupMenu *menu = new RosegardenPopupMenu((TQWidget *)tqparent());
for (int i = 0; i < getNumEntries(); ++i) {
@@ -220,7 +220,7 @@ AudioRouteMenu::getCurrentEntry()
return 0;
}
-QString
+TQString
AudioRouteMenu::getEntryText(int entry)
{
switch (m_direction) {
@@ -231,24 +231,24 @@ AudioRouteMenu::getEntryText(int entry)
if (stereo) {
if (entry < recordIns) {
- return i18n("In %1").arg(entry + 1);
+ return i18n("In %1").tqarg(entry + 1);
} else if (entry == recordIns) {
return i18n("Master");
} else {
- return i18n("Sub %1").arg(entry - recordIns);
+ return i18n("Sub %1").tqarg(entry - recordIns);
}
} else {
int channel = entry % 2;
entry /= 2;
if (entry < recordIns) {
return (channel ? i18n("In %1 R") :
- i18n("In %1 L")).arg(entry + 1);
+ i18n("In %1 L")).tqarg(entry + 1);
} else if (entry == recordIns) {
return (channel ? i18n("Master R") :
i18n("Master L"));
} else {
return (channel ? i18n("Sub %1 R") :
- i18n("Sub %1 L")).arg(entry - recordIns);
+ i18n("Sub %1 L")).tqarg(entry - recordIns);
}
}
break;
@@ -258,7 +258,7 @@ AudioRouteMenu::getEntryText(int entry)
if (entry == 0)
return i18n("Master");
else
- return i18n("Sub %1").arg(entry);
+ return i18n("Sub %1").tqarg(entry);
}
return TQString();
diff --git a/src/gui/widgets/AudioRouteMenu.h b/src/gui/widgets/AudioRouteMenu.h
index 659a57b..400d64e 100644
--- a/src/gui/widgets/AudioRouteMenu.h
+++ b/src/gui/widgets/AudioRouteMenu.h
@@ -42,15 +42,16 @@ class Studio;
class Instrument;
-class AudioRouteMenu : public QObject
+class AudioRouteMenu : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
enum Direction { In, Out };
enum Format { Compact, Regular };
- AudioRouteMenu(TQWidget *parent,
+ AudioRouteMenu(TQWidget *tqparent,
Direction direction,
Format format,
Studio *studio = 0,
diff --git a/src/gui/widgets/AudioVUMeter.cpp b/src/gui/widgets/AudioVUMeter.cpp
index d881818..adc8bb2 100644
--- a/src/gui/widgets/AudioVUMeter.cpp
+++ b/src/gui/widgets/AudioVUMeter.cpp
@@ -37,17 +37,17 @@
namespace Rosegarden
{
-AudioVUMeter::AudioVUMeter(TQWidget *parent,
+AudioVUMeter::AudioVUMeter(TQWidget *tqparent,
VUMeter::VUMeterType type,
bool stereo,
bool hasRecord,
int width,
int height,
const char *name) :
- TQWidget(parent, name),
+ TQWidget(tqparent, name),
m_stereo(stereo)
{
- setBackgroundMode(Qt::NoBackground);
+ setBackgroundMode(TQt::NoBackground);
setFixedSize(width, height);
// This offset is intended to match that for the height of the
@@ -76,11 +76,11 @@ void
AudioVUMeter::paintEvent(TQPaintEvent *e)
{
TQPainter paint(this);
- paint.setPen(colorGroup().mid());
+ paint.setPen(tqcolorGroup().mid());
paint.drawRect(0, 0, width(), height());
- paint.setPen(colorGroup().background());
- paint.setBrush(colorGroup().background());
+ paint.setPen(tqcolorGroup().background());
+ paint.setBrush(tqcolorGroup().background());
paint.drawRect(1, 1, width() - 2, m_yoff / 2 - 1);
paint.drawRect(1, 1, m_xoff / 2 - 1, height() - 2);
paint.drawRect(width() - m_xoff / 2 - 1, 1, m_xoff / 2, height() - 2);
@@ -90,14 +90,14 @@ AudioVUMeter::paintEvent(TQPaintEvent *e)
m_meter->paintEvent(e);
}
-AudioVUMeter::AudioVUMeterImpl::AudioVUMeterImpl(TQWidget *parent,
+AudioVUMeter::AudioVUMeterImpl::AudioVUMeterImpl(TQWidget *tqparent,
VUMeterType type,
bool stereo,
bool hasRecord,
int width,
int height,
const char *name) :
- VUMeter(parent, type, stereo, hasRecord, width, height, VUMeter::Vertical, name)
+ VUMeter(tqparent, type, stereo, hasRecord, width, height, VUMeter::Vertical, name)
{}
}
diff --git a/src/gui/widgets/AudioVUMeter.h b/src/gui/widgets/AudioVUMeter.h
index e59014d..73e406b 100644
--- a/src/gui/widgets/AudioVUMeter.h
+++ b/src/gui/widgets/AudioVUMeter.h
@@ -38,10 +38,10 @@ namespace Rosegarden
-class AudioVUMeter : public QWidget
+class AudioVUMeter : public TQWidget
{
public:
- AudioVUMeter(TQWidget *parent = 0,
+ AudioVUMeter(TQWidget *tqparent = 0,
VUMeter::VUMeterType type = VUMeter::AudioPeakHoldShort,
bool stereo = true,
bool hasRecord = false,
@@ -69,7 +69,7 @@ protected:
class AudioVUMeterImpl : public VUMeter
{
public:
- AudioVUMeterImpl(TQWidget *parent,
+ AudioVUMeterImpl(TQWidget *tqparent,
VUMeterType type,
bool stereo,
bool hasRecord,
diff --git a/src/gui/widgets/BigArrowButton.h b/src/gui/widgets/BigArrowButton.h
index 7adfb9b..3a51143 100644
--- a/src/gui/widgets/BigArrowButton.h
+++ b/src/gui/widgets/BigArrowButton.h
@@ -32,12 +32,12 @@ namespace Rosegarden {
class BigArrowButton : public KArrowButton
{
public:
- BigArrowButton(TQWidget *parent = 0, Qt::ArrowType arrow = Qt::UpArrow,
+ BigArrowButton(TQWidget *tqparent = 0, Qt::ArrowType arrow = Qt::UpArrow,
const char *name = 0) :
- KArrowButton(parent, arrow, name) { }
+ KArrowButton(tqparent, arrow, name) { }
virtual ~BigArrowButton() { }
- virtual TQSize sizeHint() const {
+ virtual TQSize tqsizeHint() const {
return TQSize(20, 20);
}
};
diff --git a/src/gui/widgets/CollapsingFrame.cpp b/src/gui/widgets/CollapsingFrame.cpp
index fdc351b..5835045 100644
--- a/src/gui/widgets/CollapsingFrame.cpp
+++ b/src/gui/widgets/CollapsingFrame.cpp
@@ -41,13 +41,13 @@
namespace Rosegarden
{
-CollapsingFrame::CollapsingFrame(TQString label, TQWidget *parent, const char *n) :
- TQFrame(parent, n),
+CollapsingFrame::CollapsingFrame(TQString label, TQWidget *tqparent, const char *n) :
+ TQFrame(tqparent, n),
m_widget(0),
m_fill(false),
m_collapsed(false)
{
- m_layout = new TQGridLayout(this, 3, 3, 0, 0);
+ m_tqlayout = new TQGridLayout(this, 3, 3, 0, 0);
m_toggleButton = new TQToolButton(this);
m_toggleButton->setTextLabel(label);
@@ -66,7 +66,7 @@ CollapsingFrame::CollapsingFrame(TQString label, TQWidget *parent, const char *n
connect(m_toggleButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(toggle()));
- m_layout->addMultiCellWidget(m_toggleButton, 0, 0, 0, 2);
+ m_tqlayout->addMultiCellWidget(m_toggleButton, 0, 0, 0, 2);
}
CollapsingFrame::~CollapsingFrame()
@@ -78,7 +78,7 @@ CollapsingFrame::setWidgetFill(bool fill)
m_fill = fill;
}
-QFont
+TQFont
CollapsingFrame::font() const
{
return m_toggleButton->font();
@@ -96,9 +96,9 @@ CollapsingFrame::setWidget(TQWidget *widget)
assert(!m_widget);
m_widget = widget;
if (m_fill) {
- m_layout->addMultiCellWidget(widget, 1, 1, 0, 2);
+ m_tqlayout->addMultiCellWidget(widget, 1, 1, 0, 2);
} else {
- m_layout->addWidget(widget, 1, 1);
+ m_tqlayout->addWidget(widget, 1, 1);
}
bool expanded = true;
diff --git a/src/gui/widgets/CollapsingFrame.h b/src/gui/widgets/CollapsingFrame.h
index bdce001..90a7887 100644
--- a/src/gui/widgets/CollapsingFrame.h
+++ b/src/gui/widgets/CollapsingFrame.h
@@ -40,12 +40,13 @@ namespace Rosegarden
-class CollapsingFrame : public QFrame
+class CollapsingFrame : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
- CollapsingFrame(TQString label, TQWidget *parent = 0, const char *name = 0);
+ CollapsingFrame(TQString label, TQWidget *tqparent = 0, const char *name = 0);
virtual ~CollapsingFrame();
TQFont font() const;
@@ -61,7 +62,7 @@ public slots:
void toggle();
protected:
- TQGridLayout *m_layout;
+ TQGridLayout *m_tqlayout;
TQToolButton *m_toggleButton;
TQWidget *m_widget;
bool m_fill;
diff --git a/src/gui/widgets/ColourTable.cpp b/src/gui/widgets/ColourTable.cpp
index 2cceca4..cde4dbc 100644
--- a/src/gui/widgets/ColourTable.cpp
+++ b/src/gui/widgets/ColourTable.cpp
@@ -43,8 +43,8 @@ namespace Rosegarden
{
ColourTable::ColourTable
-(TQWidget *parent, ColourMap &input, ColourList &list)
- : TQTable(1, 2, parent, "RColourTable")
+(TQWidget *tqparent, ColourMap &input, ColourList &list)
+ : TQTable(1, 2, tqparent, "RColourTable")
{
setSorting(FALSE);
setSelectionMode(TQTable::SingleRow);
diff --git a/src/gui/widgets/ColourTable.h b/src/gui/widgets/ColourTable.h
index b1e470a..3932df6 100644
--- a/src/gui/widgets/ColourTable.h
+++ b/src/gui/widgets/ColourTable.h
@@ -44,13 +44,14 @@ namespace Rosegarden
class ColourMap;
-class ColourTable : public QTable
+class ColourTable : public TQTable
{
Q_OBJECT
+ TQ_OBJECT
public:
typedef std::map<unsigned int, unsigned int, std::less<unsigned int> > ColourList;
- ColourTable(TQWidget *parent, ColourMap &input, ColourList &list);
+ ColourTable(TQWidget *tqparent, ColourMap &input, ColourList &list);
void populate_table(ColourMap &input, ColourList &list);
diff --git a/src/gui/widgets/ColourTableItem.h b/src/gui/widgets/ColourTableItem.h
index fb5b417..9f4926b 100644
--- a/src/gui/widgets/ColourTableItem.h
+++ b/src/gui/widgets/ColourTableItem.h
@@ -40,7 +40,7 @@ namespace Rosegarden
-class ColourTableItem : public QTableItem
+class ColourTableItem : public TQTableItem
{
public:
ColourTableItem(TQTable *t, const TQColor &input)
diff --git a/src/gui/widgets/CurrentProgressDialog.h b/src/gui/widgets/CurrentProgressDialog.h
index 2ca0838..90823ea 100644
--- a/src/gui/widgets/CurrentProgressDialog.h
+++ b/src/gui/widgets/CurrentProgressDialog.h
@@ -37,9 +37,10 @@ namespace Rosegarden
class ProgressDialog;
-class CurrentProgressDialog : public QObject
+class CurrentProgressDialog : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
static CurrentProgressDialog* getInstance();
@@ -64,8 +65,8 @@ public slots:
void slotCurrentProgressDialogDestroyed();
protected:
- CurrentProgressDialog(TQObject* parent, const char* name = 0)
- : TQObject(parent, name) {}
+ CurrentProgressDialog(TQObject* tqparent, const char* name = 0)
+ : TQObject(tqparent, name) {}
//--------------- Data members ---------------------------------
static CurrentProgressDialog* m_instance;
diff --git a/src/gui/widgets/DiatonicPitchChooser.cpp b/src/gui/widgets/DiatonicPitchChooser.cpp
index 6a1b8ab..13fe3b5 100644
--- a/src/gui/widgets/DiatonicPitchChooser.cpp
+++ b/src/gui/widgets/DiatonicPitchChooser.cpp
@@ -43,11 +43,11 @@ namespace Rosegarden
{
DiatonicPitchChooser::DiatonicPitchChooser(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
int defaultNote,
int defaultPitch,
int defaultOctave) :
- TQGroupBox(1, Horizontal, title, parent),
+ TQGroupBox(1, Qt::Horizontal, title, tqparent),
m_defaultPitch(defaultPitch)
{
m_pitchDragLabel = new PitchDragLabel(this, defaultPitch);
@@ -87,7 +87,7 @@ DiatonicPitchChooser::DiatonicPitchChooser(TQString title,
m_accidental->insertItem(i18n("double sharp"));
m_accidental->setCurrentItem(2); // default: natural
- m_pitchLabel = new TQLabel(TQString("%1").arg(getPitch()), hbox);
+ m_pitchLabel = new TQLabel(TQString("%1").tqarg(getPitch()), hbox);
m_pitchLabel->setMinimumWidth(40);
@@ -157,7 +157,7 @@ DiatonicPitchChooser::slotSetPitch(int pitch)
m_accidental->setCurrentItem(pitchChange + 2);
- m_pitchLabel->setText(TQString("%1").arg(pitch));
+ m_pitchLabel->setText(TQString("%1").tqarg(pitch));
update();
}
@@ -199,7 +199,7 @@ DiatonicPitchChooser::setLabelsIfNeeded()
//{
m_pitchDragLabel->slotSetPitch(getPitch(), m_octave->currentItem(), m_step->currentItem());
//}
- m_pitchLabel->setText(TQString("%1").arg(getPitch()));
+ m_pitchLabel->setText(TQString("%1").tqarg(getPitch()));
}
void
@@ -217,7 +217,7 @@ DiatonicPitchChooser::slotSetNote(int pitch, int octave, int step)
m_accidental->setCurrentItem(pitchOffset + 2);
//MidiPitchLabel pl(p);
- m_pitchLabel->setText(TQString("%1").arg(pitch));
+ m_pitchLabel->setText(TQString("%1").tqarg(pitch));
update();
}
diff --git a/src/gui/widgets/DiatonicPitchChooser.h b/src/gui/widgets/DiatonicPitchChooser.h
index bf20539..7992a76 100644
--- a/src/gui/widgets/DiatonicPitchChooser.h
+++ b/src/gui/widgets/DiatonicPitchChooser.h
@@ -42,12 +42,13 @@ namespace Rosegarden
class PitchDragLabel;
-class DiatonicPitchChooser : public QGroupBox
+class DiatonicPitchChooser : public TQGroupBox
{
Q_OBJECT
+ TQ_OBJECT
public:
DiatonicPitchChooser(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
int defaultNote = 0,
int defaultPitch = 60,
int defaultOctave = 5);
diff --git a/src/gui/widgets/Fader.cpp b/src/gui/widgets/Fader.cpp
index fc77f8e..021252e 100644
--- a/src/gui/widgets/Fader.cpp
+++ b/src/gui/widgets/Fader.cpp
@@ -45,8 +45,8 @@ Fader::PixmapCache Fader::m_pixmapCache;
Fader::Fader(AudioLevel::FaderType type,
- int w, int h, TQWidget *parent) :
- TQWidget(parent),
+ int w, int h, TQWidget *tqparent) :
+ TQWidget(tqparent),
m_integral(false),
m_vertical(h > w),
m_min(0),
@@ -56,7 +56,7 @@ Fader::Fader(AudioLevel::FaderType type,
m_float(new TextFloat(this)),
m_floatTimer(new TQTimer())
{
- setBackgroundMode(Qt::NoBackground);
+ setBackgroundMode(TQt::NoBackground);
setFixedSize(w, h); // provisional
calculateButtonPixmap();
// if (m_vertical) {
@@ -73,7 +73,7 @@ Fader::Fader(AudioLevel::FaderType type,
m_sliderMax = width() - m_sliderMin;
}
- m_outlineColour = colorGroup().mid();
+ m_outlineColour = tqcolorGroup().mid();
calculateGroovePixmap();
setFader(0.0);
@@ -83,8 +83,8 @@ Fader::Fader(AudioLevel::FaderType type,
}
Fader::Fader(int min, int max, int deflt,
- int w, int h, TQWidget *parent) :
- TQWidget(parent),
+ int w, int h, TQWidget *tqparent) :
+ TQWidget(tqparent),
m_integral(true),
m_vertical(h > w),
m_min(min),
@@ -93,7 +93,7 @@ Fader::Fader(int min, int max, int deflt,
m_float(new TextFloat(this)),
m_floatTimer(new TQTimer())
{
- setBackgroundMode(Qt::NoBackground);
+ setBackgroundMode(TQt::NoBackground);
setFixedSize(w, h); // provisional
calculateButtonPixmap();
// if (m_vertical) {
@@ -110,7 +110,7 @@ Fader::Fader(int min, int max, int deflt,
m_sliderMax = width() - m_sliderMin;
}
- m_outlineColour = colorGroup().mid();
+ m_outlineColour = tqcolorGroup().mid();
calculateGroovePixmap();
setFader(deflt);
@@ -120,8 +120,8 @@ Fader::Fader(int min, int max, int deflt,
}
Fader::Fader(int min, int max, int deflt,
- bool vertical, TQWidget *parent) :
- TQWidget(parent),
+ bool vertical, TQWidget *tqparent) :
+ TQWidget(tqparent),
m_integral(true),
m_vertical(vertical),
m_min(min),
@@ -130,7 +130,7 @@ Fader::Fader(int min, int max, int deflt,
m_float(new TextFloat(this)),
m_floatTimer(new TQTimer())
{
- setBackgroundMode(Qt::NoBackground);
+ setBackgroundMode(TQt::NoBackground);
calculateButtonPixmap();
if (m_vertical) {
@@ -141,7 +141,7 @@ Fader::Fader(int min, int max, int deflt,
m_sliderMax = width() - m_sliderMin;
}
- m_outlineColour = colorGroup().mid();
+ m_outlineColour = tqcolorGroup().mid();
calculateGroovePixmap();
setFader(deflt);
@@ -320,7 +320,7 @@ Fader::mousePressEvent(TQMouseEvent *e)
{
m_clickMousePos = -1;
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
if (e->type() == TQEvent::MouseButtonDblClick) {
setFader(0);
@@ -397,17 +397,17 @@ Fader::showFloatText()
TQString text;
if (m_integral) {
- text = TQString("%1").arg(int(m_value));
+ text = TQString("%1").tqarg(int(m_value));
} else if (m_value == AudioLevel::DB_FLOOR) {
text = "Off";
} else {
float v = fabs(m_value);
text = TQString("%1%2.%3%4%5 dB")
- .arg(m_value < 0 ? '-' : '+')
- .arg(int(v))
- .arg(int(v * 10) % 10)
- .arg(int(v * 100) % 10)
- .arg(int(v * 1000) % 10);
+ .tqarg(m_value < 0 ? '-' : '+')
+ .tqarg(int(v))
+ .tqarg(int(v * 10) % 10)
+ .tqarg(int(v * 100) % 10)
+ .tqarg(int(v * 1000) % 10);
}
m_float->setText(text);
@@ -415,12 +415,12 @@ Fader::showFloatText()
// Reposition - we need to sum the relative positions up to the
// topLevel or dialog to please move().
//
- TQWidget *par = parentWidget();
+ TQWidget *par = tqparentWidget();
TQPoint totalPos = this->pos();
- while (par->parentWidget() && !par->isTopLevel() && !par->isDialog()) {
+ while (par->tqparentWidget() && !par->isTopLevel() && !par->isDialog()) {
totalPos += par->pos();
- par = par->parentWidget();
+ par = par->tqparentWidget();
}
// Move just top/right
@@ -447,9 +447,9 @@ Fader::calculateGroovePixmap()
delete map;
map = new TQPixmap(width(), height());
- map->fill(colorGroup().background());
+ map->fill(tqcolorGroup().background());
TQPainter paint(map);
- paint.setBrush(colorGroup().background());
+ paint.setBrush(tqcolorGroup().background());
if (m_vertical) {
@@ -464,9 +464,9 @@ Fader::calculateGroovePixmap()
if (position >= 0 &&
position < m_sliderMax - m_sliderMin) {
if (dB == 0)
- paint.setPen(colorGroup().dark());
+ paint.setPen(tqcolorGroup().dark());
else
- paint.setPen(colorGroup().midlight());
+ paint.setPen(tqcolorGroup().midlight());
paint.drawLine(1, (m_sliderMax - position),
width() - 2, (m_sliderMax - position));
}
@@ -477,8 +477,8 @@ Fader::calculateGroovePixmap()
}
}
- paint.setPen(colorGroup().dark());
- paint.setBrush(colorGroup().mid());
+ paint.setPen(tqcolorGroup().dark());
+ paint.setBrush(tqcolorGroup().mid());
paint.drawRect(width() / 2 - 3, height() - m_sliderMax,
6, m_sliderMax - m_sliderMin);
paint.end();
@@ -511,48 +511,48 @@ Fader::calculateButtonPixmap()
buttonWidth = width() - 2;
map = new TQPixmap(buttonWidth, buttonHeight);
- map->fill(colorGroup().background());
+ map->fill(tqcolorGroup().background());
int x = 0;
int y = 0;
TQPainter paint(map);
- paint.setPen(colorGroup().light());
+ paint.setPen(tqcolorGroup().light());
paint.drawLine(x + 1, y, x + buttonWidth - 2, y);
paint.drawLine(x, y + 1, x, y + buttonHeight - 2);
- paint.setPen(colorGroup().midlight());
+ paint.setPen(tqcolorGroup().midlight());
paint.drawLine(x + 1, y + 1, x + buttonWidth - 2, y + 1);
paint.drawLine(x + 1, y + 1, x + 1, y + buttonHeight - 2);
- paint.setPen(colorGroup().mid());
+ paint.setPen(tqcolorGroup().mid());
paint.drawLine(x + 2, y + buttonHeight - 2, x + buttonWidth - 2,
y + buttonHeight - 2);
paint.drawLine(x + buttonWidth - 2, y + 2, x + buttonWidth - 2,
y + buttonHeight - 2);
- paint.setPen(colorGroup().dark());
+ paint.setPen(tqcolorGroup().dark());
paint.drawLine(x + 1, y + buttonHeight - 1, x + buttonWidth - 2,
y + buttonHeight - 1);
paint.drawLine(x + buttonWidth - 1, y + 1, x + buttonWidth - 1,
y + buttonHeight - 2);
- paint.setPen(colorGroup().shadow());
+ paint.setPen(tqcolorGroup().shadow());
paint.drawLine(x + 1, y + buttonHeight / 2, x + buttonWidth - 2,
y + buttonHeight / 2);
- paint.setPen(colorGroup().mid());
+ paint.setPen(tqcolorGroup().mid());
paint.drawLine(x + 1, y + buttonHeight / 2 - 1, x + buttonWidth - 2,
y + buttonHeight / 2 - 1);
paint.drawPoint(x, y + buttonHeight / 2);
- paint.setPen(colorGroup().light());
+ paint.setPen(tqcolorGroup().light());
paint.drawLine(x + 1, y + buttonHeight / 2 + 1, x + buttonWidth - 2,
y + buttonHeight / 2 + 1);
- paint.setPen(colorGroup().button());
- paint.setBrush(colorGroup().button());
+ paint.setPen(tqcolorGroup().button());
+ paint.setBrush(tqcolorGroup().button());
paint.drawRect(x + 2, y + 2, buttonWidth - 4, buttonHeight / 2 - 4);
paint.drawRect(x + 2, y + buttonHeight / 2 + 2,
buttonWidth - 4, buttonHeight / 2 - 4);
diff --git a/src/gui/widgets/Fader.h b/src/gui/widgets/Fader.h
index 60aca20..dad638b 100644
--- a/src/gui/widgets/Fader.h
+++ b/src/gui/widgets/Fader.h
@@ -46,9 +46,10 @@ namespace Rosegarden
class TextFloat;
-class Fader : public QWidget
+class Fader : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -56,21 +57,21 @@ public:
* based on the given dimensions.
*/
Fader(AudioLevel::FaderType,
- int width, int height, TQWidget *parent);
+ int width, int height, TQWidget *tqparent);
/**
* Construct a fader on an integral scale. The fader calculates
* its orientation based on the given dimensions.
*/
Fader(int min, int max, int deflt,
- int width, int height, TQWidget *parent);
+ int width, int height, TQWidget *tqparent);
/**
* Construct a fader on an integral scale, with a 1:1 ratio of
* pixel positions and values.
*/
Fader(int min, int max, int deflt,
- bool vertical, TQWidget *parent);
+ bool vertical, TQWidget *tqparent);
virtual ~Fader();
diff --git a/src/gui/widgets/HSpinBox.cpp b/src/gui/widgets/HSpinBox.cpp
index f3b5970..637c010 100644
--- a/src/gui/widgets/HSpinBox.cpp
+++ b/src/gui/widgets/HSpinBox.cpp
@@ -46,23 +46,23 @@ int HSpinBox::mapTextToValue( bool* ok )
return int(f * m_scaleFactor);
}
-HSpinBox::HSpinBox( int minV, int maxV, int step, TQWidget* parent,
+HSpinBox::HSpinBox( int minV, int maxV, int step, TQWidget* tqparent,
double bottom, double top, int decimals, float initialValue)
- : TQSpinBox(minV,maxV,step,parent)
+ : TQSpinBox(minV,maxV,step,tqparent)
{
- setValidator(new TQDoubleValidator(bottom,top,decimals,this));
+ setValidator(new TQDoubleValidator(bottom,top,decimals,TQT_TQOBJECT(this)));
initialize(decimals);
setValuef(initialValue);
}
//constructor with default settings
-HSpinBox::HSpinBox( TQWidget* parent, float initialValue, int step,
+HSpinBox::HSpinBox( TQWidget* tqparent, float initialValue, int step,
double bottom, double top, int decimals,
const TQObject* recv, const char* mem)
: TQSpinBox((int)(bottom*pow(10.0, decimals)),
- (int)(top*pow(10.0, decimals)), step, parent)
+ (int)(top*pow(10.0, decimals)), step, tqparent)
{
- setValidator(new TQDoubleValidator(bottom,top,decimals,this));
+ setValidator(new TQDoubleValidator(bottom,top,decimals,TQT_TQOBJECT(this)));
initialize(decimals);
setValuef(initialValue);
if (recv != NULL && mem != NULL)
diff --git a/src/gui/widgets/HSpinBox.h b/src/gui/widgets/HSpinBox.h
index 70baf87..584d086 100644
--- a/src/gui/widgets/HSpinBox.h
+++ b/src/gui/widgets/HSpinBox.h
@@ -35,18 +35,18 @@
namespace Rosegarden
{
-class HSpinBox : public QSpinBox
+class HSpinBox : public TQSpinBox
{
TQString mapValueToText(int j);
int mapTextToValue( bool* ok );
public:
- HSpinBox( int minV, int maxV, int step, TQWidget* parent,
+ HSpinBox( int minV, int maxV, int step, TQWidget* tqparent,
double bottom, double top, int decimals, float initialValue);
//constructor with default settings
- HSpinBox( TQWidget* parent, float initialValue = 0.2, int step=1,
+ HSpinBox( TQWidget* tqparent, float initialValue = 0.2, int step=1,
double bottom=-25.0, double top=25.0, int decimals=3,
const TQObject* recv=NULL, const char* mem=NULL);
diff --git a/src/gui/widgets/Label.h b/src/gui/widgets/Label.h
index a30b196..60c98fa 100644
--- a/src/gui/widgets/Label.h
+++ b/src/gui/widgets/Label.h
@@ -37,12 +37,13 @@ class TQMouseEvent;
namespace Rosegarden
{
-class Label : public QLabel
+class Label : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
public:
- Label(TQWidget *parent = 0, const char *name=0):
- TQLabel(parent, name) {;}
+ Label(TQWidget *tqparent = 0, const char *name=0):
+ TQLabel(tqparent, name) {;}
protected:
virtual void mouseDoubleClickEvent(TQMouseEvent * /*e*/)
diff --git a/src/gui/widgets/MidiFaderWidget.h b/src/gui/widgets/MidiFaderWidget.h
index 308d022..0e24bfa 100644
--- a/src/gui/widgets/MidiFaderWidget.h
+++ b/src/gui/widgets/MidiFaderWidget.h
@@ -43,12 +43,13 @@ class Fader;
class AudioVUMeter;
-class MidiFaderWidget : public QFrame
+class MidiFaderWidget : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
- MidiFaderWidget(TQWidget *parent,
+ MidiFaderWidget(TQWidget *tqparent,
TQString id = "");
AudioVUMeter *m_vuMeter;
diff --git a/src/gui/widgets/PitchChooser.cpp b/src/gui/widgets/PitchChooser.cpp
index 2aa1c57..b46efda 100644
--- a/src/gui/widgets/PitchChooser.cpp
+++ b/src/gui/widgets/PitchChooser.cpp
@@ -40,9 +40,9 @@ namespace Rosegarden
{
PitchChooser::PitchChooser(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
int defaultPitch) :
- TQGroupBox(1, Horizontal, title, parent),
+ TQGroupBox(1, Qt::Horizontal, title, tqparent),
m_defaultPitch(defaultPitch)
{
m_pitchDragLabel = new PitchDragLabel(this, defaultPitch);
@@ -58,7 +58,7 @@ PitchChooser::PitchChooser(TQString title,
m_pitch->setValue(defaultPitch);
MidiPitchLabel pl(defaultPitch);
- m_pitchLabel = new TQLabel(pl.getQString(), hbox);
+ m_pitchLabel = new TQLabel(pl.getTQString(), hbox);
m_pitchLabel->setMinimumWidth(40);
connect(m_pitch, TQT_SIGNAL(valueChanged(int)),
@@ -99,7 +99,7 @@ PitchChooser::slotSetPitch(int p)
m_pitchDragLabel->slotSetPitch(p);
MidiPitchLabel pl(p);
- m_pitchLabel->setText(pl.getQString());
+ m_pitchLabel->setText(pl.getTQString());
update();
}
diff --git a/src/gui/widgets/PitchChooser.h b/src/gui/widgets/PitchChooser.h
index 4c844ca..ef6dcf5 100644
--- a/src/gui/widgets/PitchChooser.h
+++ b/src/gui/widgets/PitchChooser.h
@@ -41,12 +41,13 @@ namespace Rosegarden
class PitchDragLabel;
-class PitchChooser : public QGroupBox
+class PitchChooser : public TQGroupBox
{
Q_OBJECT
+ TQ_OBJECT
public:
PitchChooser(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
int defaultPitch = 60);
int getPitch() const;
diff --git a/src/gui/widgets/PitchDragLabel.cpp b/src/gui/widgets/PitchDragLabel.cpp
index 9a174bb..55a06d5 100644
--- a/src/gui/widgets/PitchDragLabel.cpp
+++ b/src/gui/widgets/PitchDragLabel.cpp
@@ -38,10 +38,10 @@
namespace Rosegarden
{
-PitchDragLabel::PitchDragLabel(TQWidget *parent,
+PitchDragLabel::PitchDragLabel(TQWidget *tqparent,
int defaultPitch,
bool defaultSharps) :
- TQWidget(parent),
+ TQWidget(tqparent),
m_pitch(defaultPitch),
m_usingSharps(defaultSharps),
m_clickedY(0),
@@ -84,7 +84,7 @@ PitchDragLabel::slotSetPitch(int pitch, int octave, int step)
void
PitchDragLabel::mousePressEvent(TQMouseEvent *e)
{
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
m_clickedY = e->y();
m_clickedPitch = m_pitch;
m_clicked = true;
@@ -201,8 +201,8 @@ PitchDragLabel::paintEvent(TQPaintEvent *)
}
-QSize
-PitchDragLabel::sizeHint() const
+TQSize
+PitchDragLabel::tqsizeHint() const
{
return TQSize(150, 135);
}
diff --git a/src/gui/widgets/PitchDragLabel.h b/src/gui/widgets/PitchDragLabel.h
index fa3ecfd..1be7232 100644
--- a/src/gui/widgets/PitchDragLabel.h
+++ b/src/gui/widgets/PitchDragLabel.h
@@ -42,17 +42,18 @@ namespace Rosegarden
class NotePixmapFactory;
-class PitchDragLabel : public QWidget
+class PitchDragLabel : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- PitchDragLabel(TQWidget *parent,
+ PitchDragLabel(TQWidget *tqparent,
int defaultPitch = 60, bool defaultSharps = true);
~PitchDragLabel();
int getPitch() const { return m_pitch; }
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
signals:
void pitchDragged(int);
diff --git a/src/gui/widgets/PluginControl.cpp b/src/gui/widgets/PluginControl.cpp
index 69e9591..1f546da 100644
--- a/src/gui/widgets/PluginControl.cpp
+++ b/src/gui/widgets/PluginControl.cpp
@@ -43,8 +43,8 @@
namespace Rosegarden
{
-PluginControl::PluginControl(TQWidget *parent,
- TQGridLayout *layout,
+PluginControl::PluginControl(TQWidget *tqparent,
+ TQGridLayout *tqlayout,
ControlType type,
PluginPort *port,
AudioPluginManager *aPM,
@@ -52,8 +52,8 @@ PluginControl::PluginControl(TQWidget *parent,
float initialValue,
bool showBounds,
bool hidden):
- TQObject(parent),
- m_layout(layout),
+ TQObject(tqparent),
+ m_tqlayout(tqlayout),
m_type(type),
m_port(port),
m_pluginManager(aPM),
@@ -63,7 +63,7 @@ PluginControl::PluginControl(TQWidget *parent,
plainFont.setPointSize((plainFont.pointSize() * 9 ) / 10);
TQLabel *controlTitle =
- new TQLabel(TQString("%1 ").arg(strtoqstr(port->getName())), parent);
+ new TQLabel(TQString("%1 ").tqarg(strtoqstr(port->getName())), tqparent);
controlTitle->setFont(plainFont);
if (type == Rotary) {
@@ -121,9 +121,9 @@ PluginControl::PluginControl(TQWidget *parent,
TQLabel *low;
if (port->getDisplayHint() &
(PluginPort::Integer | PluginPort::Toggled)) {
- low = new TQLabel(TQString("%1").arg(int(displayLower)), parent);
+ low = new TQLabel(TQString("%1").tqarg(int(displayLower)), tqparent);
} else {
- low = new TQLabel(TQString("%1").arg(displayLower), parent);
+ low = new TQLabel(TQString("%1").tqarg(displayLower), tqparent);
}
low->setFont(plainFont);
@@ -134,7 +134,7 @@ PluginControl::PluginControl(TQWidget *parent,
// << ", actual upper " << upperBound << ", step "
// << step << std::endl;
- m_dial = new ::Rosegarden::Rotary(parent,
+ m_dial = new ::Rosegarden::Rotary(tqparent,
lowerBound, // min
upperBound, // max
step, // step
@@ -154,9 +154,9 @@ PluginControl::PluginControl(TQWidget *parent,
TQLabel *upp;
if (port->getDisplayHint() &
(PluginPort::Integer | PluginPort::Toggled)) {
- upp = new TQLabel(TQString("%1").arg(int(displayUpper)), parent);
+ upp = new TQLabel(TQString("%1").tqarg(int(displayUpper)), tqparent);
} else {
- upp = new TQLabel(TQString("%1").arg(displayUpper), parent);
+ upp = new TQLabel(TQString("%1").tqarg(displayUpper), tqparent);
}
upp->setFont(plainFont);
@@ -165,8 +165,8 @@ PluginControl::PluginControl(TQWidget *parent,
if (!hidden) {
controlTitle->show();
item = new TQWidgetItem(controlTitle);
- item->setAlignment(Qt::AlignRight | Qt::AlignBottom);
- m_layout->addItem(item);
+ item->tqsetAlignment(TQt::AlignRight | TQt::AlignBottom);
+ m_tqlayout->addItem(item);
} else {
controlTitle->hide();
}
@@ -174,8 +174,8 @@ PluginControl::PluginControl(TQWidget *parent,
if (showBounds && !hidden) {
low->show();
item = new TQWidgetItem(low);
- item->setAlignment(Qt::AlignRight | Qt::AlignBottom);
- m_layout->addItem(item);
+ item->tqsetAlignment(TQt::AlignRight | TQt::AlignBottom);
+ m_tqlayout->addItem(item);
} else {
low->hide();
}
@@ -183,8 +183,8 @@ PluginControl::PluginControl(TQWidget *parent,
if (!hidden) {
m_dial->show();
item = new TQWidgetItem(m_dial);
- item->setAlignment(Qt::AlignCenter);
- m_layout->addItem(item);
+ item->tqsetAlignment(TQt::AlignCenter);
+ m_tqlayout->addItem(item);
} else {
m_dial->hide();
}
@@ -192,8 +192,8 @@ PluginControl::PluginControl(TQWidget *parent,
if (showBounds && !hidden) {
upp->show();
item = new TQWidgetItem(upp);
- item->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
- m_layout->addItem(item);
+ item->tqsetAlignment(TQt::AlignLeft | TQt::AlignBottom);
+ m_tqlayout->addItem(item);
} else {
upp->hide();
}
diff --git a/src/gui/widgets/PluginControl.h b/src/gui/widgets/PluginControl.h
index d809d81..468bb09 100644
--- a/src/gui/widgets/PluginControl.h
+++ b/src/gui/widgets/PluginControl.h
@@ -43,9 +43,10 @@ class PluginPort;
class AudioPluginManager;
class Studio;
-class PluginControl : public QObject
+class PluginControl : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
typedef enum
@@ -55,8 +56,8 @@ public:
NumericSlider
} ControlType;
- PluginControl(TQWidget *parent,
- TQGridLayout *layout,
+ PluginControl(TQWidget *tqparent,
+ TQGridLayout *tqlayout,
ControlType type,
PluginPort *port,
AudioPluginManager *pluginManager,
@@ -83,7 +84,7 @@ protected:
//--------------- Data members ---------------------------------
- TQGridLayout *m_layout;
+ TQGridLayout *m_tqlayout;
ControlType m_type;
PluginPort *m_port;
diff --git a/src/gui/widgets/ProgressBar.h b/src/gui/widgets/ProgressBar.h
index 383a58a..2a93471 100644
--- a/src/gui/widgets/ProgressBar.h
+++ b/src/gui/widgets/ProgressBar.h
@@ -40,6 +40,7 @@ namespace Rosegarden
class ProgressBar : public KProgress
{
Q_OBJECT
+ TQ_OBJECT
public:
ProgressBar(int totalSteps,
diff --git a/src/gui/widgets/ProgressDialog.cpp b/src/gui/widgets/ProgressDialog.cpp
index 715e9ae..e8ff6ee 100644
--- a/src/gui/widgets/ProgressDialog.cpp
+++ b/src/gui/widgets/ProgressDialog.cpp
@@ -45,7 +45,7 @@ ProgressDialog::ProgressDialog(TQWidget *creator,
const char *name,
bool modal):
KProgressDialog(creator, name,
- i18n("Processing..."), TQString::null, modal),
+ i18n("Processing..."), TQString(), modal),
m_wasVisible(false),
m_frozen(false),
m_modal(modal)
@@ -107,9 +107,9 @@ ProgressDialog::polish()
KProgressDialog::polish();
if (allowCancel())
- setCursor(Qt::ArrowCursor);
+ setCursor(TQt::ArrowCursor);
else
- TQApplication::setOverrideCursor(TQCursor(Qt::waitCursor));
+ TQApplication::setOverrideCursor(TQCursor(TQt::waitCursor));
}
void ProgressDialog::hideEvent(TQHideEvent* e)
@@ -128,10 +128,10 @@ ProgressDialog::slotSetOperationName(TQString name)
// << name << ") visible : " << isVisible() << endl;
setLabel(name);
- // Little trick stolen from QProgressDialog
+ // Little trick stolen from TQProgressDialog
// increase resize only, never shrink
- int w = QMAX( isVisible() ? width() : 0, sizeHint().width() );
- int h = QMAX( isVisible() ? height() : 0, sizeHint().height() );
+ int w = TQMAX( isVisible() ? width() : 0, tqsizeHint().width() );
+ int h = TQMAX( isVisible() ? height() : 0, tqsizeHint().height() );
resize( w, h );
}
@@ -199,7 +199,7 @@ void ProgressDialog::processEvents()
// RG_DEBUG << "ProgressDialog::processEvents: modalVisible is "
// << m_modalVisible << endl;
if (m_modalVisible) {
- kapp->processEvents(50);
+ kapp->tqprocessEvents(50);
} else {
rgapp->refreshGUI(50);
}
diff --git a/src/gui/widgets/ProgressDialog.h b/src/gui/widgets/ProgressDialog.h
index 8e6e030..890c8b2 100644
--- a/src/gui/widgets/ProgressDialog.h
+++ b/src/gui/widgets/ProgressDialog.h
@@ -44,6 +44,7 @@ namespace Rosegarden
class ProgressDialog : public KProgressDialog
{
Q_OBJECT
+ TQ_OBJECT
public:
ProgressDialog(TQWidget * creator = 0,
const char * name = 0,
diff --git a/src/gui/widgets/QDeferScrollView.cpp b/src/gui/widgets/QDeferScrollView.cpp
index 38cb211..35f098e 100644
--- a/src/gui/widgets/QDeferScrollView.cpp
+++ b/src/gui/widgets/QDeferScrollView.cpp
@@ -32,10 +32,10 @@
namespace Rosegarden
{
-QDeferScrollView::QDeferScrollView(TQWidget* parent, const char *name, WFlags f)
- : TQScrollView(parent, name, f)
+QDeferScrollView::QDeferScrollView(TQWidget* tqparent, const char *name, WFlags f)
+ : TQScrollView(tqparent, name, f)
{
- setFocusPolicy(TQWidget::WheelFocus);
+ setFocusPolicy(TQ_WheelFocus);
}
void QDeferScrollView::setBottomMargin(int m)
diff --git a/src/gui/widgets/QDeferScrollView.h b/src/gui/widgets/QDeferScrollView.h
index 9ba02a9..d9a1d36 100644
--- a/src/gui/widgets/QDeferScrollView.h
+++ b/src/gui/widgets/QDeferScrollView.h
@@ -23,8 +23,8 @@
COPYING included with this distribution for more information.
*/
-#ifndef _RG_QDEFERSCROLLVIEW_H_
-#define _RG_QDEFERSCROLLVIEW_H_
+#ifndef _RG_TQDEFERSCROLLVIEW_H_
+#define _RG_TQDEFERSCROLLVIEW_H_
#include <tqscrollview.h>
@@ -53,11 +53,12 @@ namespace Rosegarden
* @see SegmentCanvas
* @see TrackEditor::m_trackButtonScroll
*/
-class QDeferScrollView : public QScrollView
+class QDeferScrollView : public TQScrollView
{
Q_OBJECT
+ TQ_OBJECT
public:
- QDeferScrollView(TQWidget* parent=0, const char *name=0, WFlags f=0);
+ QDeferScrollView(TQWidget* tqparent=0, const char *name=0, WFlags f=0);
void setBottomMargin(int);
diff --git a/src/gui/widgets/QuantizeParameters.cpp b/src/gui/widgets/QuantizeParameters.cpp
index 1cb2a58..a00969a 100644
--- a/src/gui/widgets/QuantizeParameters.cpp
+++ b/src/gui/widgets/QuantizeParameters.cpp
@@ -52,13 +52,13 @@
namespace Rosegarden
{
-QuantizeParameters::QuantizeParameters(TQWidget *parent,
+QuantizeParameters::QuantizeParameters(TQWidget *tqparent,
QuantizerType defaultQuantizer,
bool showNotationOption,
bool showAdvancedButton,
TQString configCategory,
TQString preamble) :
- TQFrame(parent),
+ TQFrame(tqparent),
m_configCategory(configCategory),
m_standardQuantizations
(BasicQuantizer::getStandardQuantizations())
@@ -71,47 +71,47 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
int zero = 0;
if (preamble) {
TQLabel *label = new TQLabel(preamble, this);
- label->setAlignment(Qt::WordBreak);
+ label->tqsetAlignment(TQt::WordBreak);
m_mainLayout->addMultiCellWidget(label, 0, 0, 0, 1);
zero = 1;
}
- TQGroupBox *quantizerBox = new QGroupBox
- (1, Horizontal, i18n("Quantizer"), this);
+ TQGroupBox *quantizerBox = new TQGroupBox
+ (1, Qt::Horizontal, i18n("Quantizer"), this);
m_mainLayout->addWidget(quantizerBox, zero, 0);
TQFrame *typeFrame = new TQFrame(quantizerBox);
- TQGridLayout *layout = new TQGridLayout(typeFrame, 2, 2, 5, 3);
- layout->addWidget(new TQLabel(i18n("Quantizer type:"), typeFrame), 0, 0);
+ TQGridLayout *tqlayout = new TQGridLayout(typeFrame, 2, 2, 5, 3);
+ tqlayout->addWidget(new TQLabel(i18n("Quantizer type:"), typeFrame), 0, 0);
m_typeCombo = new KComboBox(typeFrame);
m_typeCombo->insertItem(i18n("Grid quantizer"));
m_typeCombo->insertItem(i18n("Legato quantizer"));
m_typeCombo->insertItem(i18n("Heuristic notation quantizer"));
- layout->addWidget(m_typeCombo, 0, 1);
+ tqlayout->addWidget(m_typeCombo, 0, 1);
- m_notationTarget = new QCheckBox
+ m_notationTarget = new TQCheckBox
(i18n("Quantize for notation only (leave performance unchanged)"),
typeFrame);
- layout->addMultiCellWidget(m_notationTarget, 1, 1, 0, 1);
+ tqlayout->addMultiCellWidget(m_notationTarget, 1, 1, 0, 1);
if (!showNotationOption)
m_notationTarget->hide();
TQHBox *parameterBox = new TQHBox(this);
m_mainLayout->addWidget(parameterBox, zero + 1, 0);
- m_notationBox = new QGroupBox
- (1, Horizontal, i18n("Notation parameters"), parameterBox);
+ m_notationBox = new TQGroupBox
+ (1, Qt::Horizontal, i18n("Notation parameters"), parameterBox);
TQFrame *notationFrame = new TQFrame(m_notationBox);
- layout = new TQGridLayout(notationFrame, 4, 2, 5, 3);
+ tqlayout = new TQGridLayout(notationFrame, 4, 2, 5, 3);
- layout->addWidget(new TQLabel(i18n("Base grid unit:"), notationFrame),
+ tqlayout->addWidget(new TQLabel(i18n("Base grid unit:"), notationFrame),
1, 0);
m_notationUnitCombo = new KComboBox(notationFrame);
- layout->addWidget(m_notationUnitCombo, 1, 1);
+ tqlayout->addWidget(m_notationUnitCombo, 1, 1);
- layout->addWidget(new TQLabel(i18n("Complexity:"),
+ tqlayout->addWidget(new TQLabel(i18n("Complexity:"),
notationFrame), 0, 0);
m_simplicityCombo = new KComboBox(notationFrame);
@@ -120,9 +120,9 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
m_simplicityCombo->insertItem(i18n("Normal"));
m_simplicityCombo->insertItem(i18n("Low"));
m_simplicityCombo->insertItem(i18n("Very low"));
- layout->addWidget(m_simplicityCombo, 0, 1);
+ tqlayout->addWidget(m_simplicityCombo, 0, 1);
- layout->addWidget(new TQLabel(i18n("Tuplet level:"),
+ tqlayout->addWidget(new TQLabel(i18n("Tuplet level:"),
notationFrame), 2, 0);
m_maxTuplet = new KComboBox(notationFrame);
m_maxTuplet->insertItem(i18n("None"));
@@ -136,37 +136,37 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
m_maxTuplet->insertItem(i18n("8-Tuplet"));
*/
m_maxTuplet->insertItem(i18n("Any"));
- layout->addWidget(m_maxTuplet, 2, 1);
+ tqlayout->addWidget(m_maxTuplet, 2, 1);
m_counterpoint = new TQCheckBox(i18n("Permit counterpoint"), notationFrame);
- layout->addMultiCellWidget(m_counterpoint, 3, 3, 0, 1);
+ tqlayout->addMultiCellWidget(m_counterpoint, 3, 3, 0, 1);
- m_gridBox = new QGroupBox
- (1, Horizontal, i18n("Grid parameters"), parameterBox);
+ m_gridBox = new TQGroupBox
+ (1, Qt::Horizontal, i18n("Grid parameters"), parameterBox);
TQFrame *gridFrame = new TQFrame(m_gridBox);
- layout = new TQGridLayout(gridFrame, 4, 2, 5, 3);
+ tqlayout = new TQGridLayout(gridFrame, 4, 2, 5, 3);
- layout->addWidget(new TQLabel(i18n("Base grid unit:"), gridFrame), 0, 0);
+ tqlayout->addWidget(new TQLabel(i18n("Base grid unit:"), gridFrame), 0, 0);
m_gridUnitCombo = new KComboBox(gridFrame);
- layout->addWidget(m_gridUnitCombo, 0, 1);
+ tqlayout->addWidget(m_gridUnitCombo, 0, 1);
m_swingLabel = new TQLabel(i18n("Swing:"), gridFrame);
- layout->addWidget(m_swingLabel, 1, 0);
+ tqlayout->addWidget(m_swingLabel, 1, 0);
m_swingCombo = new KComboBox(gridFrame);
- layout->addWidget(m_swingCombo, 1, 1);
+ tqlayout->addWidget(m_swingCombo, 1, 1);
m_iterativeLabel = new TQLabel(i18n("Iterative amount:"), gridFrame);
- layout->addWidget(m_iterativeLabel, 2, 0);
+ tqlayout->addWidget(m_iterativeLabel, 2, 0);
m_iterativeCombo = new KComboBox(gridFrame);
- layout->addWidget(m_iterativeCombo, 2, 1);
+ tqlayout->addWidget(m_iterativeCombo, 2, 1);
- m_durationCheckBox = new QCheckBox
+ m_durationCheckBox = new TQCheckBox
(i18n("Quantize durations as well as start times"), gridFrame);
- layout->addMultiCellWidget(m_durationCheckBox, 3, 3, 0, 1);
+ tqlayout->addMultiCellWidget(m_durationCheckBox, 3, 3, 0, 1);
- m_postProcessingBox = new QGroupBox
- (1, Horizontal, i18n("After quantization"), this);
+ m_postProcessingBox = new TQGroupBox
+ (1, Qt::Horizontal, i18n("After quantization"), this);
if (preamble) {
m_mainLayout->addMultiCellWidget(m_postProcessingBox,
@@ -181,26 +181,26 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
if (showAdvancedButton) {
m_advancedButton =
new TQPushButton(i18n("Show advanced options"), this);
- m_mainLayout->addWidget(m_advancedButton, zero + 2, 0, Qt::AlignLeft);
+ m_mainLayout->addWidget(m_advancedButton, zero + 2, 0, TQt::AlignLeft);
TQObject::connect(m_advancedButton, TQT_SIGNAL(clicked()),
this, TQT_SLOT(slotAdvancedChanged()));
}
TQFrame *postFrame = new TQFrame(m_postProcessingBox);
- layout = new TQGridLayout(postFrame, 4, 1, 5, 3);
+ tqlayout = new TQGridLayout(postFrame, 4, 1, 5, 3);
m_rebeam = new TQCheckBox(i18n("Re-beam"), postFrame);
- m_articulate = new QCheckBox
+ m_articulate = new TQCheckBox
(i18n("Add articulations (staccato, tenuto, slurs)"), postFrame);
m_makeViable = new TQCheckBox(i18n("Tie notes at barlines etc"), postFrame);
m_deCounterpoint = new TQCheckBox(i18n("Split-and-tie overlapping chords"), postFrame);
- layout->addWidget(m_rebeam, 0, 0);
- layout->addWidget(m_articulate, 1, 0);
- layout->addWidget(m_makeViable, 2, 0);
- layout->addWidget(m_deCounterpoint, 3, 0);
+ tqlayout->addWidget(m_rebeam, 0, 0);
+ tqlayout->addWidget(m_articulate, 1, 0);
+ tqlayout->addWidget(m_makeViable, 2, 0);
+ tqlayout->addWidget(m_deCounterpoint, 3, 0);
- TQPixmap noMap = NotePixmapFactory::toQPixmap
+ TQPixmap noMap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeToolbarPixmap("menu-no-note"));
int defaultType = 0;
@@ -278,7 +278,7 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
timeT time = m_standardQuantizations[i];
timeT error = 0;
- TQPixmap pmap = NotePixmapFactory::toQPixmap
+ TQPixmap pmap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeNoteMenuPixmap(time, error));
TQString label = NotationStrings::makeNoteMenuLabel(time, false, error);
@@ -286,8 +286,8 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
m_gridUnitCombo->insertItem(pmap, label);
m_notationUnitCombo->insertItem(pmap, label);
} else {
- m_gridUnitCombo->insertItem(noMap, TQString("%1").arg(time));
- m_notationUnitCombo->insertItem(noMap, TQString("%1").arg(time));
+ m_gridUnitCombo->insertItem(noMap, TQString("%1").tqarg(time));
+ m_notationUnitCombo->insertItem(noMap, TQString("%1").tqarg(time));
}
if (m_standardQuantizations[i] == defaultUnit) {
@@ -298,14 +298,14 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
}
for (int i = -100; i <= 200; i += 10) {
- m_swingCombo->insertItem(i == 0 ? i18n("None") : TQString("%1%").arg(i));
+ m_swingCombo->insertItem(i == 0 ? i18n("None") : TQString("%1%").tqarg(i));
if (i == defaultSwing)
m_swingCombo->setCurrentItem(m_swingCombo->count() - 1);
}
for (int i = 10; i <= 100; i += 10) {
m_iterativeCombo->insertItem(i == 100 ? i18n("Full quantize") :
- TQString("%1%").arg(i));
+ TQString("%1%").tqarg(i));
if (i == defaultIterate)
m_iterativeCombo->setCurrentItem(m_iterativeCombo->count() - 1);
}
diff --git a/src/gui/widgets/QuantizeParameters.h b/src/gui/widgets/QuantizeParameters.h
index 8efd0c5..97a6350 100644
--- a/src/gui/widgets/QuantizeParameters.h
+++ b/src/gui/widgets/QuantizeParameters.h
@@ -23,8 +23,8 @@
COPYING included with this distribution for more information.
*/
-#ifndef _RG_ROSEGARDENQUANTIZEPARAMETERS_H_
-#define _RG_ROSEGARDENQUANTIZEPARAMETERS_H_
+#ifndef _RG_ROSEGARDENTQUANTIZEPARAMETERS_H_
+#define _RG_ROSEGARDENTQUANTIZEPARAMETERS_H_
#include <tqframe.h>
#include <tqstring.h>
@@ -47,13 +47,14 @@ namespace Rosegarden
class Quantizer;
-class QuantizeParameters : public QFrame
+class QuantizeParameters : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
enum QuantizerType { Grid, Legato, Notation };
- QuantizeParameters(TQWidget *parent,
+ QuantizeParameters(TQWidget *tqparent,
QuantizerType defaultQuantizer,
bool showNotationOption,
bool showAdvancedButton,
diff --git a/src/gui/widgets/RosegardenPopupMenu.h b/src/gui/widgets/RosegardenPopupMenu.h
index 8bc81cb..f16b2f7 100644
--- a/src/gui/widgets/RosegardenPopupMenu.h
+++ b/src/gui/widgets/RosegardenPopupMenu.h
@@ -29,11 +29,11 @@
namespace Rosegarden {
-class RosegardenPopupMenu : public QPopupMenu
+class RosegardenPopupMenu : public TQPopupMenu
{
// just to make itemHeight public
public:
- RosegardenPopupMenu(TQWidget *parent) : TQPopupMenu(parent) { }
+ RosegardenPopupMenu(TQWidget *tqparent) : TQPopupMenu(tqparent) { }
using TQPopupMenu::itemHeight;
};
diff --git a/src/gui/widgets/Rotary.cpp b/src/gui/widgets/Rotary.cpp
index f7cd1ec..a011275 100644
--- a/src/gui/widgets/Rotary.cpp
+++ b/src/gui/widgets/Rotary.cpp
@@ -60,7 +60,7 @@ static TQTimer *_floatTimer = 0;
Rotary::PixmapCache Rotary::m_pixmaps;
-Rotary::Rotary(TQWidget *parent,
+Rotary::Rotary(TQWidget *tqparent,
float minValue,
float maxValue,
float step,
@@ -71,7 +71,7 @@ Rotary::Rotary(TQWidget *parent,
bool snapToTicks,
bool centred,
bool logarithmic) :
- TQWidget(parent),
+ TQWidget(tqparent),
m_minValue(minValue),
m_maxValue(maxValue),
m_step(step),
@@ -89,7 +89,7 @@ Rotary::Rotary(TQWidget *parent,
m_knobColour(0, 0, 0),
m_logarithmic(logarithmic)
{
- setBackgroundMode(Qt::NoBackground);
+ setBackgroundMode(TQt::NoBackground);
if (!_float)
_float = new TextFloat(this);
@@ -133,7 +133,7 @@ void
Rotary::setKnobColour(const TQColor &colour)
{
m_knobColour = colour;
- repaint();
+ tqrepaint();
}
void
@@ -187,7 +187,7 @@ Rotary::paintEvent(TQPaintEvent *)
pen.setWidth(scale);
paint.setPen(pen);
- if (m_knobColour != Qt::black) {
+ if (m_knobColour != TQt::black) {
paint.setBrush(m_knobColour);
} else {
paint.setBrush(
@@ -223,7 +223,7 @@ Rotary::paintEvent(TQPaintEvent *)
paint.setBrush(TQBrush::NoBrush);
- pen.setColor(colorGroup().dark());
+ pen.setColor(tqcolorGroup().dark());
pen.setWidth(scale);
paint.setPen(pen);
@@ -253,7 +253,7 @@ Rotary::paintEvent(TQPaintEvent *)
paint.setPen(pen);
int shadowAngle = -720;
- c = colorGroup().dark();
+ c = tqcolorGroup().dark();
for (int arc = 120; arc < 2880; arc += 240) {
pen.setColor(c);
paint.setPen(pen);
@@ -263,7 +263,7 @@ Rotary::paintEvent(TQPaintEvent *)
}
shadowAngle = 2160;
- c = colorGroup().dark();
+ c = tqcolorGroup().dark();
for (int arc = 120; arc < 2880; arc += 240) {
pen.setColor(c);
paint.setPen(pen);
@@ -289,7 +289,7 @@ Rotary::paintEvent(TQPaintEvent *)
double y = hyp + len * cos(angle);
pen.setWidth(scale * 2);
- pen.setColor(colorGroup().dark());
+ pen.setColor(tqcolorGroup().dark());
paint.setPen(pen);
paint.drawLine(int(x0), int(y0), int(x), int(y));
@@ -373,17 +373,17 @@ Rotary::snapPosition()
void
Rotary::mousePressEvent(TQMouseEvent *e)
{
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
m_buttonPressed = true;
m_lastY = e->y();
m_lastX = e->x();
- } else if (e->button() == MidButton) // reset to default
+ } else if (e->button() == Qt::MidButton) // reset to default
{
m_position = m_initialPosition;
snapPosition();
update();
emit valueChanged(m_snapPosition);
- } else if (e->button() == RightButton) // reset to centre position
+ } else if (e->button() == Qt::RightButton) // reset to centre position
{
m_position = (m_maxValue + m_minValue) / 2.0;
snapPosition();
@@ -391,23 +391,23 @@ Rotary::mousePressEvent(TQMouseEvent *e)
emit valueChanged(m_snapPosition);
}
- TQPoint totalPos = mapTo(topLevelWidget(), TQPoint(0, 0));
+ TQPoint totalPos = mapTo(tqtopLevelWidget(), TQPoint(0, 0));
if (!_float)
_float = new TextFloat(this);
_float->reparent(this);
_float->move(totalPos + TQPoint(width() + 2, -height() / 2));
if (m_logarithmic) {
- _float->setText(TQString("%1").arg(powf(10, m_position)));
+ _float->setText(TQString("%1").tqarg(powf(10, m_position)));
} else {
- _float->setText(TQString("%1").arg(m_position));
+ _float->setText(TQString("%1").tqarg(m_position));
}
_float->show();
// std::cerr << "Rotary::mousePressEvent: logarithmic = " << m_logarithmic
// << ", position = " << m_position << std::endl;
- if (e->button() == RightButton || e->button() == MidButton) {
+ if (e->button() == Qt::RightButton || e->button() == Qt::MidButton) {
// one shot, 500ms
_floatTimer->start(500, true);
}
@@ -455,7 +455,7 @@ Rotary::mouseDoubleClickEvent(TQMouseEvent * /*e*/)
void
Rotary::mouseReleaseEvent(TQMouseEvent *e)
{
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
m_buttonPressed = false;
m_lastY = 0;
m_lastX = 0;
@@ -498,9 +498,9 @@ Rotary::mouseMoveEvent(TQMouseEvent *e)
// draw on the float text
if (m_logarithmic) {
- _float->setText(TQString("%1").arg(powf(10, m_snapPosition)));
+ _float->setText(TQString("%1").tqarg(powf(10, m_snapPosition)));
} else {
- _float->setText(TQString("%1").arg(m_snapPosition));
+ _float->setText(TQString("%1").tqarg(m_snapPosition));
}
}
}
@@ -527,15 +527,15 @@ Rotary::wheelEvent(TQWheelEvent *e)
// draw on the float text
if (m_logarithmic) {
- _float->setText(TQString("%1").arg(powf(10, m_snapPosition)));
+ _float->setText(TQString("%1").tqarg(powf(10, m_snapPosition)));
} else {
- _float->setText(TQString("%1").arg(m_snapPosition));
+ _float->setText(TQString("%1").tqarg(m_snapPosition));
}
// Reposition - we need to sum the relative positions up to the
// topLevel or dialog to please move(). Move just top/right of the rotary
//
- TQPoint totalPos = mapTo(topLevelWidget(), TQPoint(0, 0));
+ TQPoint totalPos = mapTo(tqtopLevelWidget(), TQPoint(0, 0));
_float->reparent(this);
_float->move(totalPos + TQPoint(width() + 2, -height() / 2));
_float->show();
diff --git a/src/gui/widgets/Rotary.h b/src/gui/widgets/Rotary.h
index cecff8c..f399eab 100644
--- a/src/gui/widgets/Rotary.h
+++ b/src/gui/widgets/Rotary.h
@@ -42,9 +42,10 @@ namespace Rosegarden
-class Rotary : public QWidget
+class Rotary : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
enum TickMode {
@@ -55,7 +56,7 @@ public:
StepTicks // end points plus every step interval
};
- Rotary(TQWidget *parent,
+ Rotary(TQWidget *tqparent,
float minValue = 0.0,
float maxValue = 100.0,
float step = 1.0,
diff --git a/src/gui/widgets/ScrollBox.cpp b/src/gui/widgets/ScrollBox.cpp
index d129a08..66e32e2 100644
--- a/src/gui/widgets/ScrollBox.cpp
+++ b/src/gui/widgets/ScrollBox.cpp
@@ -43,8 +43,8 @@
namespace Rosegarden
{
-ScrollBox::ScrollBox(TQWidget* parent, SizeMode sizeMode, const char* name) :
- TQFrame(parent, name),
+ScrollBox::ScrollBox(TQWidget* tqparent, SizeMode sizeMode, const char* name) :
+ TQFrame(tqparent, name),
m_sizeMode(sizeMode)
{
setFrameStyle(Panel | Sunken);
@@ -53,15 +53,15 @@ ScrollBox::ScrollBox(TQWidget* parent, SizeMode sizeMode, const char* name) :
void ScrollBox::mousePressEvent(TQMouseEvent* e)
{
m_mouse = e->pos();
- if (e->button() == RightButton)
+ if (e->button() == Qt::RightButton)
emit button3Pressed();
- if (e->button() == MidButton)
+ if (e->button() == Qt::MidButton)
emit button2Pressed();
}
void ScrollBox::mouseMoveEvent(TQMouseEvent* e)
{
- if (e->state() != LeftButton)
+ if (e->state() != Qt::LeftButton)
return ;
int dx = (e->pos().x() - m_mouse.x()) * m_pagesize.width() / width();
@@ -80,7 +80,7 @@ void ScrollBox::drawContents(TQPainter* paint)
TQRect c(contentsRect());
- paint->setPen(Qt::red);
+ paint->setPen(TQt::red);
int len = m_pagesize.width();
int x = c.x() + c.width() * m_viewpos.x() / len;
@@ -123,36 +123,36 @@ void ScrollBox::setPageSize(const TQSize& s)
setFixedWidth(width);
}
- repaint();
+ tqrepaint();
}
void ScrollBox::setViewSize(const TQSize& s)
{
m_viewsize = s;
- repaint();
+ tqrepaint();
}
void ScrollBox::setViewPos(const TQPoint& pos)
{
m_viewpos = pos;
- repaint();
+ tqrepaint();
}
void ScrollBox::setViewX(int x)
{
m_viewpos = TQPoint(x, m_viewpos.y());
- repaint();
+ tqrepaint();
}
void ScrollBox::setViewY(int y)
{
m_viewpos = TQPoint(m_viewpos.x(), y);
- repaint();
+ tqrepaint();
}
void ScrollBox::setThumbnail(TQPixmap img)
{
- setPaletteBackgroundPixmap(img.convertToImage().smoothScale(size()));
+ setPaletteBackgroundPixmap(TQPixmap(img.convertToImage().smoothScale(size())));
}
}
diff --git a/src/gui/widgets/ScrollBox.h b/src/gui/widgets/ScrollBox.h
index ebd99a8..aeca48d 100644
--- a/src/gui/widgets/ScrollBox.h
+++ b/src/gui/widgets/ScrollBox.h
@@ -44,14 +44,15 @@ class TQMouseEvent;
namespace Rosegarden
{
-class ScrollBox: public QFrame
+class ScrollBox: public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
enum SizeMode { FixWidth, FixHeight };
- ScrollBox(TQWidget *parent = 0,
+ ScrollBox(TQWidget *tqparent = 0,
SizeMode mode = FixWidth,
const char *name = 0);
diff --git a/src/gui/widgets/ScrollBoxDialog.cpp b/src/gui/widgets/ScrollBoxDialog.cpp
index 008c868..f262605 100644
--- a/src/gui/widgets/ScrollBoxDialog.cpp
+++ b/src/gui/widgets/ScrollBoxDialog.cpp
@@ -38,11 +38,11 @@
namespace Rosegarden
{
-ScrollBoxDialog::ScrollBoxDialog(TQWidget *parent,
+ScrollBoxDialog::ScrollBoxDialog(TQWidget *tqparent,
ScrollBox::SizeMode sizeMode,
const char *name,
WFlags flags) :
- KDialog(parent, name, flags),
+ KDialog(tqparent, name, flags),
m_scrollbox(new ScrollBox(this, sizeMode))
{ }
diff --git a/src/gui/widgets/ScrollBoxDialog.h b/src/gui/widgets/ScrollBoxDialog.h
index a4478c1..722f518 100644
--- a/src/gui/widgets/ScrollBoxDialog.h
+++ b/src/gui/widgets/ScrollBoxDialog.h
@@ -43,9 +43,10 @@ namespace Rosegarden
class ScrollBoxDialog : public KDialog
{
Q_OBJECT
+ TQ_OBJECT
public:
- ScrollBoxDialog(TQWidget *parent = 0,
+ ScrollBoxDialog(TQWidget *tqparent = 0,
ScrollBox::SizeMode mode = ScrollBox::FixWidth,
const char *name = 0,
WFlags flags = 0);
diff --git a/src/gui/widgets/SpinBox.cpp b/src/gui/widgets/SpinBox.cpp
index 64bd300..ec77fda 100644
--- a/src/gui/widgets/SpinBox.cpp
+++ b/src/gui/widgets/SpinBox.cpp
@@ -34,11 +34,11 @@
namespace Rosegarden
{
-SpinBox::SpinBox(TQWidget *parent, const char *name):
- TQSpinBox(parent, name), m_doubleValue(0)
+SpinBox::SpinBox(TQWidget *tqparent, const char *name):
+ TQSpinBox(tqparent, name), m_doubleValue(0)
{}
-QString
+TQString
SpinBox::mapValueToText(int value)
{
TQString doubleStr;
diff --git a/src/gui/widgets/SpinBox.h b/src/gui/widgets/SpinBox.h
index 804935b..25d99bb 100644
--- a/src/gui/widgets/SpinBox.h
+++ b/src/gui/widgets/SpinBox.h
@@ -41,13 +41,14 @@ namespace Rosegarden
/**
* A Combobox that just about handles doubles - you have
* to set the precision outside of this class if you're
- * using it with Qt designer. Urch.
+ * using it with TQt designer. Urch.
*/
-class SpinBox : public QSpinBox
+class SpinBox : public TQSpinBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- SpinBox(TQWidget *parent = 0, const char *name=0);
+ SpinBox(TQWidget *tqparent = 0, const char *name=0);
double getDoubleValue() const { return m_doubleValue; }
diff --git a/src/gui/widgets/TextFloat.h b/src/gui/widgets/TextFloat.h
index b9463aa..d68cd4d 100644
--- a/src/gui/widgets/TextFloat.h
+++ b/src/gui/widgets/TextFloat.h
@@ -38,15 +38,15 @@ namespace Rosegarden
-class TextFloat : public QWidget
+class TextFloat : public TQWidget
{
public:
- TextFloat(TQWidget *parent);
+ TextFloat(TQWidget *tqparent);
virtual ~TextFloat() {;}
void setText(const TQString &text);
- // Reparent the float correctly by context
+ // Retqparent the float correctly by context
//
void reparent(TQWidget *newParent);
diff --git a/src/gui/widgets/TimeWidget.cpp b/src/gui/widgets/TimeWidget.cpp
index 8eced3a..df177a4 100644
--- a/src/gui/widgets/TimeWidget.cpp
+++ b/src/gui/widgets/TimeWidget.cpp
@@ -48,12 +48,12 @@ namespace Rosegarden
{
TimeWidget::TimeWidget(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
Composition *composition,
timeT absTime,
bool editable,
bool constrainToCompositionDuration) :
- TQGroupBox(1, Horizontal, title, parent),
+ TQGroupBox(1, Qt::Horizontal, title, tqparent),
m_composition(composition),
m_isDuration(false),
m_constrain(constrainToCompositionDuration),
@@ -65,13 +65,13 @@ TimeWidget::TimeWidget(TQString title,
}
TimeWidget::TimeWidget(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
Composition *composition,
timeT startTime,
timeT duration,
bool editable,
bool constrainToCompositionDuration) :
- TQGroupBox(1, Horizontal, title, parent),
+ TQGroupBox(1, Qt::Horizontal, title, tqparent),
m_composition(composition),
m_isDuration(true),
m_constrain(constrainToCompositionDuration),
@@ -93,14 +93,14 @@ TimeWidget::init(bool editable)
editable = true;
TQFrame *frame = new TQFrame(this);
- TQGridLayout *layout = new TQGridLayout(frame, 7, 3, 5, 5);
+ TQGridLayout *tqlayout = new TQGridLayout(frame, 7, 3, 5, 5);
TQLabel *label = 0;
if (m_isDuration) {
label = new TQLabel(i18n("Note:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 0, 0);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 0, 0);
if (editable) {
m_note = new TQComboBox(frame);
@@ -118,7 +118,7 @@ TimeWidget::init(bool editable)
timeT error = 0;
TQString label = NotationStrings::makeNoteMenuLabel
(dottedDuration, false, error);
- TQPixmap pmap = NotePixmapFactory::toQPixmap
+ TQPixmap pmap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeNoteMenuPixmap(dottedDuration, error));
m_note->insertItem(pmap, label); // ignore error
}
@@ -127,13 +127,13 @@ TimeWidget::init(bool editable)
timeT error = 0;
TQString label = NotationStrings::makeNoteMenuLabel
(duration, false, error);
- TQPixmap pmap = NotePixmapFactory::toQPixmap
+ TQPixmap pmap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeNoteMenuPixmap(duration, error));
m_note->insertItem(pmap, label); // ignore error
}
connect(m_note, TQT_SIGNAL(activated(int)),
this, TQT_SLOT(slotNoteChanged(int)));
- layout->addMultiCellWidget(m_note, 0, 0, 1, 3);
+ tqlayout->addMultiCellWidget(m_note, 0, 0, 1, 3);
} else {
@@ -145,12 +145,12 @@ TimeWidget::init(bool editable)
label = i18n("<inexact>");
TQLineEdit *le = new TQLineEdit(label, frame);
le->setReadOnly(true);
- layout->addMultiCellWidget(le, 0, 0, 1, 3);
+ tqlayout->addMultiCellWidget(le, 0, 0, 1, 3);
}
label = new TQLabel(i18n("Units:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 0, 4);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 0, 4);
if (editable) {
m_timeT = new TQSpinBox(frame);
@@ -158,12 +158,12 @@ TimeWidget::init(bool editable)
(Note(Note::Shortest).getDuration());
connect(m_timeT, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotTimeTChanged(int)));
- layout->addWidget(m_timeT, 0, 5);
+ tqlayout->addWidget(m_timeT, 0, 5);
} else {
m_timeT = 0;
- TQLineEdit *le = new TQLineEdit(TQString("%1").arg(m_time), frame);
+ TQLineEdit *le = new TQLineEdit(TQString("%1").tqarg(m_time), frame);
le->setReadOnly(true);
- layout->addWidget(le, 0, 5);
+ tqlayout->addWidget(le, 0, 5);
}
} else {
@@ -171,8 +171,8 @@ TimeWidget::init(bool editable)
m_note = 0;
label = new TQLabel(i18n("Time:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 0, 0);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 0, 0);
if (editable) {
m_timeT = new TQSpinBox(frame);
@@ -180,19 +180,19 @@ TimeWidget::init(bool editable)
(Note(Note::Shortest).getDuration());
connect(m_timeT, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotTimeTChanged(int)));
- layout->addWidget(m_timeT, 0, 1);
- layout->addWidget(new TQLabel(i18n("units"), frame), 0, 2);
+ tqlayout->addWidget(m_timeT, 0, 1);
+ tqlayout->addWidget(new TQLabel(i18n("units"), frame), 0, 2);
} else {
m_timeT = 0;
- TQLineEdit *le = new TQLineEdit(TQString("%1").arg(m_time), frame);
+ TQLineEdit *le = new TQLineEdit(TQString("%1").tqarg(m_time), frame);
le->setReadOnly(true);
- layout->addWidget(le, 0, 2);
+ tqlayout->addWidget(le, 0, 2);
}
}
label = new TQLabel(m_isDuration ? i18n("Measures:") : i18n("Measure:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 1, 0);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 1, 0);
if (editable) {
m_barLabel = 0;
@@ -201,17 +201,17 @@ TimeWidget::init(bool editable)
m_bar->setMinValue(0);
connect(m_bar, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotBarBeatOrFractionChanged(int)));
- layout->addWidget(m_bar, 1, 1);
+ tqlayout->addWidget(m_bar, 1, 1);
} else {
m_bar = 0;
m_barLabel = new TQLineEdit(frame);
m_barLabel->setReadOnly(true);
- layout->addWidget(m_barLabel, 1, 1);
+ tqlayout->addWidget(m_barLabel, 1, 1);
}
label = new TQLabel(m_isDuration ? i18n("beats:") : i18n("beat:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 1, 2);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 1, 2);
if (editable) {
m_beatLabel = 0;
@@ -219,20 +219,20 @@ TimeWidget::init(bool editable)
m_beat->setMinValue(1);
connect(m_beat, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotBarBeatOrFractionChanged(int)));
- layout->addWidget(m_beat, 1, 3);
+ tqlayout->addWidget(m_beat, 1, 3);
} else {
m_beat = 0;
m_beatLabel = new TQLineEdit(frame);
m_beatLabel->setReadOnly(true);
- layout->addWidget(m_beatLabel, 1, 3);
+ tqlayout->addWidget(m_beatLabel, 1, 3);
}
- label = new TQLabel(i18n("%1:").arg(NotationStrings::getShortNoteName
+ label = new TQLabel(i18n("%1:").tqarg(NotationStrings::getShortNoteName
(Note
(Note::Shortest), true)),
frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 1, 4);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 1, 4);
if (editable) {
m_fractionLabel = 0;
@@ -240,20 +240,20 @@ TimeWidget::init(bool editable)
m_fraction->setMinValue(1);
connect(m_fraction, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotBarBeatOrFractionChanged(int)));
- layout->addWidget(m_fraction, 1, 5);
+ tqlayout->addWidget(m_fraction, 1, 5);
} else {
m_fraction = 0;
m_fractionLabel = new TQLineEdit(frame);
m_fractionLabel->setReadOnly(true);
- layout->addWidget(m_fractionLabel, 1, 5);
+ tqlayout->addWidget(m_fractionLabel, 1, 5);
}
m_timeSig = new TQLabel(frame);
- layout->addWidget(m_timeSig, 1, 6);
+ tqlayout->addWidget(m_timeSig, 1, 6);
label = new TQLabel(i18n("Seconds:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 2, 0);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 2, 0);
if (editable) {
m_secLabel = 0;
@@ -262,17 +262,17 @@ TimeWidget::init(bool editable)
m_sec->setMinValue(0);
connect(m_sec, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotSecOrMSecChanged(int)));
- layout->addWidget(m_sec, 2, 1);
+ tqlayout->addWidget(m_sec, 2, 1);
} else {
m_sec = 0;
m_secLabel = new TQLineEdit(frame);
m_secLabel->setReadOnly(true);
- layout->addWidget(m_secLabel, 2, 1);
+ tqlayout->addWidget(m_secLabel, 2, 1);
}
label = new TQLabel(i18n("msec:"), frame);
- label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
- layout->addWidget(label, 2, 2);
+ label->tqsetAlignment(TQt::AlignRight | TQt::AlignVCenter);
+ tqlayout->addWidget(label, 2, 2);
if (editable) {
m_msecLabel = 0;
@@ -281,17 +281,17 @@ TimeWidget::init(bool editable)
m_msec->setLineStep(10);
connect(m_msec, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(slotSecOrMSecChanged(int)));
- layout->addWidget(m_msec, 2, 3);
+ tqlayout->addWidget(m_msec, 2, 3);
} else {
m_msec = 0;
m_msecLabel = new TQLineEdit(frame);
m_msecLabel->setReadOnly(true);
- layout->addWidget(m_msecLabel, 2, 3);
+ tqlayout->addWidget(m_msecLabel, 2, 3);
}
if (m_isDuration) {
m_tempo = new TQLabel(frame);
- layout->addWidget(m_tempo, 2, 6);
+ tqlayout->addWidget(m_tempo, 2, 6);
} else {
m_tempo = 0;
}
@@ -383,7 +383,7 @@ TimeWidget::populate()
}
m_bar->setValue(bars);
} else {
- m_barLabel->setText(TQString("%1").arg(bars));
+ m_barLabel->setText(TQString("%1").tqarg(bars));
}
if (m_beat) {
@@ -391,7 +391,7 @@ TimeWidget::populate()
m_beat->setMaxValue(timeSig.getBeatsPerBar() - 1);
m_beat->setValue(beats);
} else {
- m_beatLabel->setText(TQString("%1").arg(beats));
+ m_beatLabel->setText(TQString("%1").tqarg(beats));
}
if (m_fraction) {
@@ -401,10 +401,10 @@ TimeWidget::populate()
getDuration() - 1);
m_fraction->setValue(hemidemis);
} else {
- m_fractionLabel->setText(TQString("%1").arg(hemidemis));
+ m_fractionLabel->setText(TQString("%1").tqarg(hemidemis));
}
- m_timeSig->setText(i18n("(%1/%2 time)").arg(timeSig.getNumerator()).
+ m_timeSig->setText(i18n("(%1/%2 time)").tqarg(timeSig.getNumerator()).
arg(timeSig.getDenominator()));
timeT endTime = m_startTime + m_time;
@@ -422,7 +422,7 @@ TimeWidget::populate()
}
m_sec->setValue(rt.sec);
} else {
- m_secLabel->setText(TQString("%1").arg(rt.sec));
+ m_secLabel->setText(TQString("%1").tqarg(rt.sec));
}
if (m_msec) {
@@ -430,7 +430,7 @@ TimeWidget::populate()
m_msec->setMaxValue(999);
m_msec->setValue(rt.msec());
} else {
- m_msecLabel->setText(TQString("%1").arg(rt.msec()));
+ m_msecLabel->setText(TQString("%1").tqarg(rt.msec()));
}
bool change = (m_composition->getTempoChangeNumberAt(endTime) !=
@@ -507,7 +507,7 @@ TimeWidget::populate()
}
m_bar->setValue(bar + 1);
} else {
- m_barLabel->setText(TQString("%1").arg(bar + 1));
+ m_barLabel->setText(TQString("%1").tqarg(bar + 1));
}
if (m_beat) {
@@ -515,7 +515,7 @@ TimeWidget::populate()
m_beat->setMaxValue(timeSig.getBeatsPerBar());
m_beat->setValue(beat);
} else {
- m_beatLabel->setText(TQString("%1").arg(beat));
+ m_beatLabel->setText(TQString("%1").tqarg(beat));
}
if (m_fraction) {
@@ -525,10 +525,10 @@ TimeWidget::populate()
getDuration() - 1);
m_fraction->setValue(hemidemis);
} else {
- m_fractionLabel->setText(TQString("%1").arg(hemidemis));
+ m_fractionLabel->setText(TQString("%1").tqarg(hemidemis));
}
- m_timeSig->setText(i18n("(%1/%2 time)").arg(timeSig.getNumerator()).
+ m_timeSig->setText(i18n("(%1/%2 time)").tqarg(timeSig.getNumerator()).
arg(timeSig.getDenominator()));
RealTime rt = m_composition->getElapsedRealTime(m_time);
@@ -543,7 +543,7 @@ TimeWidget::populate()
}
m_sec->setValue(rt.sec);
} else {
- m_secLabel->setText(TQString("%1").arg(rt.sec));
+ m_secLabel->setText(TQString("%1").tqarg(rt.sec));
}
if (m_msec) {
@@ -551,7 +551,7 @@ TimeWidget::populate()
m_msec->setMaxValue(999);
m_msec->setValue(rt.msec());
} else {
- m_msecLabel->setText(TQString("%1").arg(rt.msec()));
+ m_msecLabel->setText(TQString("%1").tqarg(rt.msec()));
}
}
diff --git a/src/gui/widgets/TimeWidget.h b/src/gui/widgets/TimeWidget.h
index 874981d..4ede052 100644
--- a/src/gui/widgets/TimeWidget.h
+++ b/src/gui/widgets/TimeWidget.h
@@ -46,15 +46,16 @@ namespace Rosegarden
class Composition;
-class TimeWidget : public QGroupBox
+class TimeWidget : public TQGroupBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor for absolute time widget
*/
TimeWidget(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
Composition *composition, // for bar/beat/msec
timeT initialTime,
bool editable = true,
@@ -66,7 +67,7 @@ public:
* correct real-time (based on tempo at startTime) etc.
*/
TimeWidget(TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
Composition *composition, // for bar/beat/msec
timeT startTime,
timeT initialDuration,
diff --git a/src/gui/widgets/TristateCheckBox.h b/src/gui/widgets/TristateCheckBox.h
index 30e7db0..4d8f318 100644
--- a/src/gui/widgets/TristateCheckBox.h
+++ b/src/gui/widgets/TristateCheckBox.h
@@ -42,12 +42,13 @@ namespace Rosegarden
* and allows us to click only between on and off
* and only to _show_ the third ("Some") state
*/
-class TristateCheckBox : public QCheckBox
+class TristateCheckBox : public TQCheckBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- TristateCheckBox(TQWidget *parent=0,
- const char *name=0):TQCheckBox(parent, name)
+ TristateCheckBox(TQWidget *tqparent=0,
+ const char *name=0):TQCheckBox(tqparent, name)
{ setTristate(true) ;}
virtual ~TristateCheckBox();
diff --git a/src/gui/widgets/VUMeter.cpp b/src/gui/widgets/VUMeter.cpp
index 1a6d90d..d963cc6 100644
--- a/src/gui/widgets/VUMeter.cpp
+++ b/src/gui/widgets/VUMeter.cpp
@@ -40,19 +40,19 @@
namespace Rosegarden
{
-VUMeter::VUMeter(TQWidget *parent,
+VUMeter::VUMeter(TQWidget *tqparent,
VUMeterType type,
bool stereo,
bool hasRecord,
int width,
int height,
- VUAlignment alignment,
+ VUAlignment tqalignment,
const char *name):
- TQLabel(parent, name),
+ TQLabel(tqparent, name),
m_originalHeight(height),
m_active(true),
m_type(type),
- m_alignment(alignment),
+ m_tqalignment(tqalignment),
m_levelLeft(0),
m_recordLevelLeft(0),
m_peakLevelLeft(0),
@@ -121,7 +121,7 @@ VUMeter::VUMeter(TQWidget *parent,
setMinimumSize(width, m_originalHeight);
setMaximumSize(width, m_originalHeight);
- if (m_alignment == Vertical)
+ if (m_tqalignment == Vertical)
m_maxLevel = height;
else
m_maxLevel = width;
@@ -153,7 +153,7 @@ VUMeter::VUMeter(TQWidget *parent,
red = max * 92 / 100;
orange = max * 60 / 100;
green = max * 10 / 100;
- m_background = Qt::black;
+ m_background = TQt::black;
}
if (m_type == AudioPeakHoldLong ||
@@ -336,7 +336,7 @@ VUMeter::paintEvent(TQPaintEvent *e)
drawMeterLevel(&paint);
- paint.setPen(colorGroup().background());
+ paint.setPen(tqcolorGroup().background());
paint.drawPoint(0, 0);
paint.drawPoint(width() - 1, 0);
paint.drawPoint(0, height() - 1);
@@ -376,12 +376,12 @@ VUMeter::drawColouredBar(TQPainter *paint, int channel,
m_type == AudioPeakHoldIEC ||
m_type == AudioPeakHoldIECLong) {
- Qt::BrushStyle style = Qt::SolidPattern;
+ TQt::BrushStyle style = TQt::SolidPattern;
int medium = m_velocityColour->getMediumKnee(),
loud = m_velocityColour->getLoudKnee();
- if (m_alignment == Vertical) {
+ if (m_tqalignment == Vertical) {
if (h > loud) {
paint->setPen(m_velocityColour->getLoudColour());
paint->setBrush(TQBrush(m_velocityColour->getLoudColour(),
@@ -397,7 +397,7 @@ VUMeter::drawColouredBar(TQPainter *paint, int channel,
}
}
- if (m_alignment == Vertical) {
+ if (m_tqalignment == Vertical) {
if (h > medium) {
paint->setPen(m_velocityColour->getMediumColour());
paint->setBrush(TQBrush(m_velocityColour->getMediumColour(),
@@ -415,7 +415,7 @@ VUMeter::drawColouredBar(TQPainter *paint, int channel,
}
}
- if (m_alignment == Vertical) {
+ if (m_tqalignment == Vertical) {
paint->setPen(m_velocityColour->getQuietColour());
paint->setBrush(TQBrush(m_velocityColour->getQuietColour(),
style));
@@ -458,7 +458,7 @@ VUMeter::drawMeterLevel(TQPainter* paint)
loud = m_velocityColour->getLoudKnee();
if (m_stereo) {
- if (m_alignment == VUMeter::Vertical) {
+ if (m_tqalignment == VUMeter::Vertical) {
int hW = width() / 2;
int midWidth = 1;
@@ -492,12 +492,12 @@ VUMeter::drawMeterLevel(TQPainter* paint)
y = height() - h;
if (h > loud) {
- paint->setPen(Qt::red); // brighter than the red meter bar
+ paint->setPen(TQt::red); // brighter than the red meter bar
paint->drawLine(0, y - 1, hW - midWidth - 1, y - 1);
paint->drawLine(0, y + 1, hW - midWidth - 1, y + 1);
}
- paint->setPen(Qt::white);
+ paint->setPen(TQt::white);
paint->drawLine(0, y, hW - midWidth - 1, y);
}
@@ -524,13 +524,13 @@ VUMeter::drawMeterLevel(TQPainter* paint)
y = height() - h;
if (h > loud) {
- paint->setPen(Qt::red); // brighter than the red meter bar
+ paint->setPen(TQt::red); // brighter than the red meter bar
paint->drawLine(hW + midWidth, y - 1, width(), y - 1);
paint->drawLine(hW + midWidth, y + 1, width(), y + 1);
}
- paint->setPen(Qt::white);
- paint->setBrush(Qt::white);
+ paint->setPen(TQt::white);
+ paint->setBrush(TQt::white);
paint->drawLine(hW + midWidth, y, width(), y);
}
@@ -545,8 +545,8 @@ VUMeter::drawMeterLevel(TQPainter* paint)
paint->drawRect(0, 0, x, height());
if (m_showPeakLevel) {
- paint->setPen(Qt::white);
- paint->setBrush(Qt::white);
+ paint->setPen(TQt::white);
+ paint->setBrush(TQt::white);
// show peak level
x = m_peakLevelLeft * width() / m_maxLevel;
@@ -561,7 +561,7 @@ VUMeter::drawMeterLevel(TQPainter* paint)
} else {
// Paint a vertical meter according to type
//
- if (m_alignment == VUMeter::Vertical) {
+ if (m_tqalignment == VUMeter::Vertical) {
int y = height() - (m_levelLeft * height()) / m_maxLevel;
drawColouredBar(paint, 0, 0, y, width(), height());
@@ -575,8 +575,8 @@ VUMeter::drawMeterLevel(TQPainter* paint)
*/
if (m_showPeakLevel) {
- paint->setPen(Qt::white);
- paint->setBrush(Qt::white);
+ paint->setPen(TQt::white);
+ paint->setBrush(TQt::white);
y = height() - (m_peakLevelLeft * height()) / m_maxLevel;
@@ -592,8 +592,8 @@ VUMeter::drawMeterLevel(TQPainter* paint)
paint->drawRect(x, 0, width() - x, height());
if (m_showPeakLevel) {
- paint->setPen(Qt::white);
- paint->setBrush(Qt::white);
+ paint->setPen(TQt::white);
+ paint->setBrush(TQt::white);
// show peak level
x = (m_peakLevelLeft * width()) / m_maxLevel;
diff --git a/src/gui/widgets/VUMeter.h b/src/gui/widgets/VUMeter.h
index fd75b9a..610d87c 100644
--- a/src/gui/widgets/VUMeter.h
+++ b/src/gui/widgets/VUMeter.h
@@ -42,9 +42,10 @@ namespace Rosegarden
class VelocityColour;
-class VUMeter : public QLabel
+class VUMeter : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
public:
typedef enum
@@ -82,13 +83,13 @@ protected:
// Constructor is protected - we can only create an object
// from a sub-class of this type from a sub-class.
//
- VUMeter(TQWidget *parent = 0,
+ VUMeter(TQWidget *tqparent = 0,
VUMeterType type = Plain,
bool stereo = false,
bool hasRecord = false,
int width = 0,
int height = 0,
- VUAlignment alignment = Horizontal,
+ VUAlignment tqalignment = Horizontal,
const char *name = 0);
~VUMeter();
@@ -114,7 +115,7 @@ private:
int x, int y, int w, int h);
VUMeterType m_type;
- VUAlignment m_alignment;
+ VUAlignment m_tqalignment;
TQColor m_background;
short m_maxLevel;
diff --git a/src/gui/widgets/WheelyButton.h b/src/gui/widgets/WheelyButton.h
index 050fd9b..17dd803 100644
--- a/src/gui/widgets/WheelyButton.h
+++ b/src/gui/widgets/WheelyButton.h
@@ -38,9 +38,10 @@ namespace Rosegarden
-class WheelyButton : public QPushButton
+class WheelyButton : public TQPushButton
{
Q_OBJECT
+ TQ_OBJECT
public:
WheelyButton(TQWidget *w) : TQPushButton(w) { }
diff --git a/src/gui/widgets/ZoomSlider.h b/src/gui/widgets/ZoomSlider.h
index 9f4235a..9cf58ab 100644
--- a/src/gui/widgets/ZoomSlider.h
+++ b/src/gui/widgets/ZoomSlider.h
@@ -40,7 +40,7 @@ namespace Rosegarden
template <class T>
-class ZoomSlider : public QSlider
+class ZoomSlider : public TQSlider
{
public:
@@ -60,7 +60,7 @@ public:
* to the user as a nice continuous range.
*/
ZoomSlider(const std::vector<T> &sizes, T defaultValue,
- Orientation, TQWidget * parent, const char * name=0);
+ Qt::Orientation, TQWidget * tqparent, const char * name=0);
virtual ~ZoomSlider();
@@ -84,10 +84,10 @@ protected:
template<class T>
ZoomSlider<T>::ZoomSlider(const std::vector<T> &sizes,
- T initialSize, Orientation o,
- TQWidget *parent, const char *name) :
+ T initialSize, Qt::Orientation o,
+ TQWidget *tqparent, const char *name) :
TQSlider(0, sizes.size()-1, 1,
- getIndex(sizes, initialSize), o, parent, name),
+ getIndex(sizes, initialSize), o, tqparent, name),
m_sizes(sizes),
m_defaultValue(initialSize)
{
diff --git a/src/gui/widgets/TextFloat.cpp b/src/gui/widgets/TextFloat.cpp
index b1f5cfd..a62f3a1 100644
--- a/src/gui/widgets/TextFloat.cpp
+++ b/src/gui/widgets/TextFloat.cpp
@@ -39,12 +39,12 @@
namespace Rosegarden
{
-TextFloat::TextFloat(TQWidget *parent):
- TQWidget(parent, "TextFloat",
+TextFloat::TextFloat(TQWidget *tqparent):
+ TQWidget(tqparent, "TextFloat",
WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop),
m_text("")
{
- reparent(parentWidget());
+ reparent(tqparentWidget());
resize(20, 20);
}
@@ -55,15 +55,15 @@ TextFloat::reparent(TQWidget *newParent)
// Get position and reparent to either top level or dialog
//
- while (newParent->parentWidget() && !newParent->isTopLevel()
+ while (newParent->tqparentWidget() && !newParent->isTopLevel()
&& !newParent->isDialog()) {
- newParent = newParent->parentWidget();
+ newParent = newParent->tqparentWidget();
position += newParent->pos();
}
// Position this widget to the right of the parent
//
- //move(pos + TQPoint(parent->width() + 5, 5));
+ //move(pos + TQPoint(tqparent->width() + 5, 5));
TQWidget::reparent(newParent,
WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop,
@@ -85,11 +85,11 @@ TextFloat::paintEvent(TQPaintEvent *e)
TQFontMetrics metrics(paint.fontMetrics());
- TQRect r = metrics.boundingRect(0, 0, 400, 400, Qt::AlignAuto, m_text);
+ TQRect r = metrics.boundingRect(0, 0, 400, 400, TQt::AlignAuto, m_text);
resize(r.width() + 7, r.height() + 7);
paint.drawRect(0, 0, r.width() + 6, r.height() + 6);
- paint.setPen(Qt::black);
- paint.drawText(TQRect(3, 3, r.width(), r.height()), Qt::AlignAuto, m_text);
+ paint.setPen(TQt::black);
+ paint.drawText(TQRect(3, 3, r.width(), r.height()), TQt::AlignAuto, m_text);
/*
TQRect textBound = metrics.boundingRect(m_text);
@@ -97,7 +97,7 @@ TextFloat::paintEvent(TQPaintEvent *e)
resize(textBound.width() + 7, textBound.height() + 7);
paint.drawRect(0, 0, textBound.width() + 6, textBound.height() + 6);
- paint.setPen(Qt::black);
+ paint.setPen(TQt::black);
paint.drawText(3, textBound.height() + 3, m_text);
*/
}
@@ -106,7 +106,7 @@ void
TextFloat::setText(const TQString &text)
{
m_text = text;
- repaint();
+ tqrepaint();
}
}
@@ -55,15 +55,15 @@ TextFloat::reparent(TQWidget *newParent)
position += newParent->pos();
}
- // Position this widget to the right of the parent
+ // Position this widget to the right of the tqparent
//